Class: Aws::DynamoDB::EndpointParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/endpoint_parameters.rb

Overview

Endpoint parameters used to influence endpoints per request.

Constant Summary collapse

PARAM_MAP =
{
  'Region' => :region,
  'UseDualStack' => :use_dual_stack,
  'UseFIPS' => :use_fips,
  'Endpoint' => :endpoint,
  'AccountId' => :account_id,
  'AccountIdEndpointMode' => :account_id_endpoint_mode,
  'ResourceArn' => :resource_arn,
  'ResourceArnList' => :resource_arn_list,
  'IsSearchOperation' => :is_search_operation,
}.freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ EndpointParameters



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 86

def initialize(options = {})
  self[:region] = options[:region]
  self[:use_dual_stack] = options[:use_dual_stack]
  self[:use_dual_stack] = false if self[:use_dual_stack].nil?
  self[:use_fips] = options[:use_fips]
  self[:use_fips] = false if self[:use_fips].nil?
  self[:endpoint] = options[:endpoint]
  self[:account_id] = options[:account_id]
  self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  self[:resource_arn] = options[:resource_arn]
  self[:resource_arn_list] = options[:resource_arn_list]
  self[:is_search_operation] = options[:is_search_operation]
end

Instance Attribute Details

#account_idstring

The AWS AccountId used for the request.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#account_id_endpoint_modestring

The AccountId Endpoint Mode.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#endpointstring

Override the endpoint used to send this request



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#is_search_operationboolean

Set to true for SearchVectors to route to the Search FQDN



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#regionstring

The AWS region used to dispatch the request.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#resource_arnstring

ResourceArn containing arn of resource



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#resource_arn_liststringArray

ResourceArnList containing list of resource arns



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#use_dual_stackboolean

When true, use the dual-stack endpoint. If the configured endpoint does not support dual-stack, dispatching the request MAY return an error.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#use_fipsboolean

When true, send this request to the FIPS-compliant regional endpoint. If the configured endpoint does not have a FIPS compliant endpoint, dispatching the request will return an error.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 58

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :account_id,
  :account_id_endpoint_mode,
  :resource_arn,
  :resource_arn_list,
  :is_search_operation,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
      'ResourceArn' => :resource_arn,
      'ResourceArnList' => :resource_arn_list,
      'IsSearchOperation' => :is_search_operation,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
    self[:resource_arn] = options[:resource_arn]
    self[:resource_arn_list] = options[:resource_arn_list]
    self[:is_search_operation] = options[:is_search_operation]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

Class Method Details

.create(config, options = {}) ⇒ Object



100
101
102
103
104
105
106
107
108
109
# File 'lib/aws-sdk-dynamodb/endpoint_parameters.rb', line 100

def self.create(config, options={})
  new({
    region: config.region,
    use_dual_stack: config.use_dualstack_endpoint,
    use_fips: config.use_fips_endpoint,
    endpoint: (config.endpoint.to_s unless config.regional_endpoint),
    account_id: config.credentials.credentials.,
    account_id_endpoint_mode: config.,
  }.merge(options))
end