Class: Aws::DynamoDB::EndpointProvider

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-dynamodb/endpoint_provider.rb

Instance Method Summary collapse

Instance Method Details

#resolve_endpoint(parameters) ⇒ Object

Raises:

  • (ArgumentError)


12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/aws-sdk-dynamodb/endpoint_provider.rb', line 12

def resolve_endpoint(parameters)
  if Aws::Endpoints::Matchers.set?(parameters.endpoint) && Aws::Endpoints::Matchers.set?(parameters.region) && (partition_result = Aws::Endpoints::Matchers.aws_partition(parameters.region)) && (parsed_endpoint = Aws::Endpoints::Matchers.parse_url(parameters.endpoint))
    if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)
      raise ArgumentError, "Invalid Configuration: FIPS and custom endpoint are not supported"
    end
    if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_dual_stack, true)
      raise ArgumentError, "Invalid Configuration: Dualstack and custom endpoint are not supported"
    end
    if Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_endpoint, "authority"), "dynamodb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}")
      raise ArgumentError, "Endpoint override is not supported for dual-stack endpoints. Please enable dual-stack functionality by enabling the configuration. For more details, see: https://docs.aws.amazon.com/sdkref/latest/guide/feature-endpoints.html"
    end
    if Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_endpoint, "authority"), "search-dynamodb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}")
      raise ArgumentError, "Endpoint override is not supported for dual-stack endpoints. Please enable dual-stack functionality by enabling the configuration. For more details, see: https://docs.aws.amazon.com/sdkref/latest/guide/feature-endpoints.html"
    end
    return Aws::Endpoints::Endpoint.new(url: "#{parameters.endpoint}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
  end
  if Aws::Endpoints::Matchers.set?(parameters.endpoint)
    if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)
      raise ArgumentError, "Invalid Configuration: FIPS and custom endpoint are not supported"
    end
    if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_dual_stack, true)
      raise ArgumentError, "Invalid Configuration: Dualstack and custom endpoint are not supported"
    end
    return Aws::Endpoints::Endpoint.new(url: "#{parameters.endpoint}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
  end
  if Aws::Endpoints::Matchers.set?(parameters.region)
    if (partition_result = Aws::Endpoints::Matchers.aws_partition(parameters.region))
      if Aws::Endpoints::Matchers.string_equals?(parameters.region, "local")
        if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)
          raise ArgumentError, "Invalid Configuration: FIPS and local endpoint are not supported"
        end
        if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_dual_stack, true)
          raise ArgumentError, "Invalid Configuration: Dualstack and local endpoint are not supported"
        end
        return Aws::Endpoints::Endpoint.new(url: "http://localhost:8000", headers: {}, properties: {"authSchemes" => [{"signingRegion" => "us-east-1", "name" => "sigv4", "signingName" => "dynamodb"}]}, metadata: { account_id_endpoint: false })
      end
      if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true) && Aws::Endpoints::Matchers.boolean_equals?(parameters.use_dual_stack, true)
        if Aws::Endpoints::Matchers.boolean_equals?(Aws::Endpoints::Matchers.attr(partition_result, "supportsFIPS"), true) && Aws::Endpoints::Matchers.boolean_equals?(Aws::Endpoints::Matchers.attr(partition_result, "supportsDualStack"), true)
          if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.string_equals?(parameters., "required")
            raise ArgumentError, "Invalid Configuration: AccountIdEndpointMode is required and FIPS is enabled, but FIPS account endpoints are not supported"
          end
          if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
            return Aws::Endpoints::Endpoint.new(url: "https://search-dynamodb-fips.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
          end
          return Aws::Endpoints::Endpoint.new(url: "https://dynamodb-fips.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
        end
        raise ArgumentError, "FIPS and DualStack are enabled, but this partition does not support one or both"
      end
      if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)
        if Aws::Endpoints::Matchers.boolean_equals?(Aws::Endpoints::Matchers.attr(partition_result, "supportsFIPS"), true)
          if Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws-us-gov")
            if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.string_equals?(parameters., "required")
              raise ArgumentError, "Invalid Configuration: AccountIdEndpointMode is required and FIPS is enabled, but FIPS account endpoints are not supported"
            end
            if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
              return Aws::Endpoints::Endpoint.new(url: "https://search-dynamodb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
            end
            return Aws::Endpoints::Endpoint.new(url: "https://dynamodb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
          end
          if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.string_equals?(parameters., "required")
            raise ArgumentError, "Invalid Configuration: AccountIdEndpointMode is required and FIPS is enabled, but FIPS account endpoints are not supported"
          end
          if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
            return Aws::Endpoints::Endpoint.new(url: "https://search-dynamodb-fips.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
          end
          return Aws::Endpoints::Endpoint.new(url: "https://dynamodb-fips.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
        end
        raise ArgumentError, "FIPS is enabled but this partition does not support FIPS"
      end
      if Aws::Endpoints::Matchers.boolean_equals?(parameters.use_dual_stack, true)
        if Aws::Endpoints::Matchers.boolean_equals?(Aws::Endpoints::Matchers.attr(partition_result, "supportsDualStack"), true)
          if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.string_equals?(parameters., "disabled")) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws") && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)) && Aws::Endpoints::Matchers.set?(parameters.resource_arn) && (parsed_arn = Aws::Endpoints::Matchers.aws_parse_arn(parameters.resource_arn)) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "service"), "dynamodb") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), false) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), "#{parameters.region}") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "accountId"), false)
            if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
              return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.search-ddb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
            end
            return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.ddb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
          end
          if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.string_equals?(parameters., "disabled")) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws") && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)) && Aws::Endpoints::Matchers.set?(parameters.resource_arn_list) && (first_arn = Aws::Endpoints::Matchers.attr(parameters.resource_arn_list, "[0]")) && (parsed_arn = Aws::Endpoints::Matchers.aws_parse_arn(first_arn)) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "service"), "dynamodb") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), false) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), "#{parameters.region}") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "accountId"), false)
            if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
              return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.search-ddb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
            end
            return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.ddb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
          end
          if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.string_equals?(parameters., "disabled")) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws") && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)) && Aws::Endpoints::Matchers.set?(parameters.)
            if Aws::Endpoints::Matchers.valid_host_label?(parameters., false)
              if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
                return Aws::Endpoints::Endpoint.new(url: "https://#{parameters.}.search-ddb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: true })
              end
              return Aws::Endpoints::Endpoint.new(url: "https://#{parameters.}.ddb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: true })
            end
            raise ArgumentError, "Credentials-sourced account ID parameter is invalid"
          end
          if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.string_equals?(parameters., "required")
            if Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true))
              if Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws")
                raise ArgumentError, "AccountIdEndpointMode is required but no AccountID was provided or able to be loaded"
              end
              raise ArgumentError, "Invalid Configuration: AccountIdEndpointMode is required but account endpoints are not supported in this partition"
            end
            raise ArgumentError, "Invalid Configuration: AccountIdEndpointMode is required and FIPS is enabled, but FIPS account endpoints are not supported"
          end
          if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
            return Aws::Endpoints::Endpoint.new(url: "https://search-dynamodb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
          end
          return Aws::Endpoints::Endpoint.new(url: "https://dynamodb.#{parameters.region}.#{partition_result['dualStackDnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
        end
        raise ArgumentError, "DualStack is enabled but this partition does not support DualStack"
      end
      if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.string_equals?(parameters., "disabled")) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws") && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)) && Aws::Endpoints::Matchers.set?(parameters.resource_arn) && (parsed_arn = Aws::Endpoints::Matchers.aws_parse_arn(parameters.resource_arn)) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "service"), "dynamodb") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), false) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), "#{parameters.region}") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "accountId"), false)
        if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
          return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.search-ddb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
        end
        return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.ddb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
      end
      if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.string_equals?(parameters., "disabled")) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws") && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)) && Aws::Endpoints::Matchers.set?(parameters.resource_arn_list) && (first_arn = Aws::Endpoints::Matchers.attr(parameters.resource_arn_list, "[0]")) && (parsed_arn = Aws::Endpoints::Matchers.aws_parse_arn(first_arn)) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "service"), "dynamodb") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), false) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(parsed_arn, "region"), "#{parameters.region}") && Aws::Endpoints::Matchers.valid_host_label?(Aws::Endpoints::Matchers.attr(parsed_arn, "accountId"), false)
        if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
          return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.search-ddb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
        end
        return Aws::Endpoints::Endpoint.new(url: "https://#{parsed_arn['accountId']}.ddb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: false })
      end
      if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.string_equals?(parameters., "disabled")) && Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws") && Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true)) && Aws::Endpoints::Matchers.set?(parameters.)
        if Aws::Endpoints::Matchers.valid_host_label?(parameters., false)
          if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
            return Aws::Endpoints::Endpoint.new(url: "https://#{parameters.}.search-ddb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: true })
          end
          return Aws::Endpoints::Endpoint.new(url: "https://#{parameters.}.ddb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {"metricValues" => ["O"]}, metadata: { account_id_endpoint: true })
        end
        raise ArgumentError, "Credentials-sourced account ID parameter is invalid"
      end
      if Aws::Endpoints::Matchers.set?(parameters.) && Aws::Endpoints::Matchers.string_equals?(parameters., "required")
        if Aws::Endpoints::Matchers.not(Aws::Endpoints::Matchers.boolean_equals?(parameters.use_fips, true))
          if Aws::Endpoints::Matchers.string_equals?(Aws::Endpoints::Matchers.attr(partition_result, "name"), "aws")
            raise ArgumentError, "AccountIdEndpointMode is required but no AccountID was provided or able to be loaded"
          end
          raise ArgumentError, "Invalid Configuration: AccountIdEndpointMode is required but account endpoints are not supported in this partition"
        end
        raise ArgumentError, "Invalid Configuration: AccountIdEndpointMode is required and FIPS is enabled, but FIPS account endpoints are not supported"
      end
      if Aws::Endpoints::Matchers.set?(parameters.is_search_operation) && Aws::Endpoints::Matchers.boolean_equals?(parameters.is_search_operation, true)
        return Aws::Endpoints::Endpoint.new(url: "https://search-dynamodb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
      end
      return Aws::Endpoints::Endpoint.new(url: "https://dynamodb.#{parameters.region}.#{partition_result['dnsSuffix']}", headers: {}, properties: {}, metadata: { account_id_endpoint: false })
    end
  end
  raise ArgumentError, "Invalid Configuration: Missing Region"
  raise ArgumentError, 'No endpoint could be resolved'

end