Class: Aws::DynamoDB::Resource
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Resource
- Defined in:
- sig/resource.rbs,
lib/aws-sdk-dynamodb/resource.rb
Overview
This class provides a resource oriented interface for DynamoDB. To create a resource object:
resource = Aws::DynamoDB::Resource.new(region: 'us-west-2')
You can supply a client object with custom configuration that will be used for all resource operations.
If you do not pass :client, a default client will be constructed.
client = Aws::DynamoDB::Client.new(region: 'us-west-2')
resource = Aws::DynamoDB::Resource.new(client: client)
Actions collapse
- #batch_get_item(options = {}) ⇒ Types::BatchGetItemOutput
- #batch_write_item(options = {}) ⇒ Types::BatchWriteItemOutput
- #create_table(options = {}) ⇒ Table
Associations collapse
Instance Method Summary collapse
- #client ⇒ Client
-
#initialize(options = {}) ⇒ Resource
constructor
A new instance of Resource.
Constructor Details
Instance Method Details
#batch_get_item(options = {}) ⇒ Types::BatchGetItemOutput
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
dynamo_db.batch_get_item({
request_items: { # required
"TableArn" => {
keys: [ # required
{
"AttributeName" => "value", # value <Hash,Array,String,Numeric,Boolean,IO,Set,nil>
},
],
attributes_to_get: ["AttributeName"],
consistent_read: false,
projection_expression: "ProjectionExpression",
expression_attribute_names: {
"ExpressionAttributeNameVariable" => "AttributeName",
},
},
},
return_consumed_capacity: "INDEXES", # accepts INDEXES, TOTAL, NONE
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:request_items
(required, Hash<String,Types::KeysAndAttributes>)
—
A map of one or more table names or table ARNs and, for each table, a map that describes one or more items to retrieve from that table. Each table name or ARN can be used only once per
BatchGetItemrequest.Each element in the map of items to retrieve consists of the following:
-
ConsistentRead- Iftrue, a strongly consistent read is used; iffalse(the default), an eventually consistent read is used. -
ExpressionAttributeNames- One or more substitution tokens for attribute names in theProjectionExpressionparameter. The following are some use cases for usingExpressionAttributeNames: -
To access an attribute whose name conflicts with a DynamoDB reserved word.
-
To create a placeholder for repeating occurrences of an attribute name in an expression.
-
To prevent special characters in an attribute name from being misinterpreted in an expression. Use the # character in an expression to dereference an attribute name. For example, consider the following attribute name:
-
Percentile
^ The name of this attribute conflicts with a reserved word, so it cannot be used directly in an expression. (For the complete list of reserved words, see Reserved Words in the Amazon DynamoDB Developer Guide). To work around this, you could specify the following for
ExpressionAttributeNames:* `{"#P":"Percentile"}` ^ You could then use this substitution in an expression, as in this example: * `#P = :val` ^ <note markdown="1"> Tokens that begin with the **\:** character are *expression attribute values*, which are placeholders for the actual value at runtime.For more information about expression attribute names, see [Accessing Item Attributes][2] in the *Amazon DynamoDB Developer Guide*.-
Keys- An array of primary key attribute values that define specific items in the table. For each primary key, you must provide all of the key attributes. For example, with a simple primary key, you only need to provide the partition key value. For a composite key, you must provide both the partition key value and the sort key value. -
ProjectionExpression- A string that identifies one or more attributes to retrieve from the table. These attributes can include scalars, sets, or elements of a JSON document. The attributes in the expression must be separated by commas.If no attribute names are specified, then all attributes are returned. If any of the requested attributes are not found, they do not appear in the result.
For more information, see Accessing Item Attributes in the Amazon DynamoDB Developer Guide.
-
AttributesToGet- This is a legacy parameter. UseProjectionExpressioninstead. For more information, see AttributesToGet in the Amazon DynamoDB Developer Guide.
-
-
:return_consumed_capacity
(String)
—
Determines the level of detail about either provisioned or on-demand throughput consumption that is returned in the response:
-
INDEXES- The response includes the aggregateConsumedCapacityfor the operation, together withConsumedCapacityfor each table and secondary index that was accessed.Note that some operations, such as
GetItemandBatchGetItem, do not access any indexes at all. In these cases, specifyingINDEXESwill only returnConsumedCapacityinformation for table(s). -
TOTAL- The response includes only the aggregateConsumedCapacityfor the operation. -
NONE- NoConsumedCapacitydetails are included in the response.
-
Returns:
88 |
# File 'sig/resource.rbs', line 88
def batch_get_item: (
|
#batch_write_item(options = {}) ⇒ Types::BatchWriteItemOutput
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
dynamo_db.batch_write_item({
request_items: { # required
"TableArn" => [
{
put_request: {
item: { # required
"AttributeName" => "value", # value <Hash,Array,String,Numeric,Boolean,IO,Set,nil>
},
},
delete_request: {
key: { # required
"AttributeName" => "value", # value <Hash,Array,String,Numeric,Boolean,IO,Set,nil>
},
},
},
],
},
return_consumed_capacity: "INDEXES", # accepts INDEXES, TOTAL, NONE
return_item_collection_metrics: "SIZE", # accepts SIZE, NONE
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:request_items
(required, Hash<String,Array>)
—
A map of one or more table names or table ARNs and, for each table, a list of operations to be performed (
DeleteRequestorPutRequest). Each element in the map consists of the following:-
DeleteRequest- Perform aDeleteItemoperation on the specified item. The item to be deleted is identified by aKeysubelement: -
Key- A map of primary key attribute values that uniquely identify the item. Each entry in this map consists of an attribute name and an attribute value. For each primary key, you must provide all of the key attributes. For example, with a simple primary key, you only need to provide a value for the partition key. For a composite primary key, you must provide values for both the partition key and the sort key.
^
-
PutRequest- Perform aPutItemoperation on the specified item. The item to be put is identified by anItemsubelement: -
Item- A map of attributes and their values. Each entry in this map consists of an attribute name and an attribute value. Attribute values must not be null; string and binary type attributes must have lengths greater than zero; and set type attributes must not be empty. Requests that contain empty values are rejected with aValidationExceptionexception.If you specify any attributes that are part of an index key, then the data types for those attributes must match those of the schema in the table's attribute definition.
-
-
:return_consumed_capacity
(String)
—
Determines the level of detail about either provisioned or on-demand throughput consumption that is returned in the response:
-
INDEXES- The response includes the aggregateConsumedCapacityfor the operation, together withConsumedCapacityfor each table and secondary index that was accessed.Note that some operations, such as
GetItemandBatchGetItem, do not access any indexes at all. In these cases, specifyingINDEXESwill only returnConsumedCapacityinformation for table(s). -
TOTAL- The response includes only the aggregateConsumedCapacityfor the operation. -
NONE- NoConsumedCapacitydetails are included in the response.
-
-
:return_item_collection_metrics
(String)
—
Determines whether item collection metrics are returned. If set to
SIZE, the response includes statistics about item collections, if any, that were modified during the operation are returned in the response. If set toNONE(the default), no statistics are returned.
Returns:
103 |
# File 'sig/resource.rbs', line 103
def batch_write_item: (
|
#client ⇒ Client
Returns:
- (Client)
32 |
# File 'lib/aws-sdk-dynamodb/resource.rb', line 32
def client: () -> Client
|
#create_table(options = {}) ⇒ Table
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
table = dynamo_db.create_table({
attribute_definitions: [
{
attribute_name: "KeySchemaAttributeName", # required
attribute_type: "S", # required, accepts S, N, B
},
],
table_name: "TableArn", # required
key_schema: [
{
attribute_name: "KeySchemaAttributeName", # required
key_type: "HASH", # required, accepts HASH, RANGE
},
],
local_secondary_indexes: [
{
index_name: "IndexName", # required
key_schema: [ # required
{
attribute_name: "KeySchemaAttributeName", # required
key_type: "HASH", # required, accepts HASH, RANGE
},
],
projection: { # required
projection_type: "ALL", # accepts ALL, KEYS_ONLY, INCLUDE
non_key_attributes: ["NonKeyAttributeName"],
},
},
],
global_secondary_indexes: [
{
index_name: "IndexName", # required
key_schema: [ # required
{
attribute_name: "KeySchemaAttributeName", # required
key_type: "HASH", # required, accepts HASH, RANGE
},
],
projection: { # required
projection_type: "ALL", # accepts ALL, KEYS_ONLY, INCLUDE
non_key_attributes: ["NonKeyAttributeName"],
},
provisioned_throughput: {
read_capacity_units: 1, # required
write_capacity_units: 1, # required
},
on_demand_throughput: {
max_read_request_units: 1,
max_write_request_units: 1,
},
warm_throughput: {
read_units_per_second: 1,
write_units_per_second: 1,
},
},
],
billing_mode: "PROVISIONED", # accepts PROVISIONED, PAY_PER_REQUEST
provisioned_throughput: {
read_capacity_units: 1, # required
write_capacity_units: 1, # required
},
stream_specification: {
stream_enabled: false, # required
stream_view_type: "NEW_IMAGE", # accepts NEW_IMAGE, OLD_IMAGE, NEW_AND_OLD_IMAGES, KEYS_ONLY
},
sse_specification: {
enabled: false,
sse_type: "AES256", # accepts AES256, KMS
kms_master_key_id: "KMSMasterKeyId",
},
tags: [
{
key: "TagKeyString", # required
value: "TagValueString", # required
},
],
table_class: "STANDARD", # accepts STANDARD, STANDARD_INFREQUENT_ACCESS
deletion_protection_enabled: false,
warm_throughput: {
read_units_per_second: 1,
write_units_per_second: 1,
},
resource_policy: "ResourcePolicy",
on_demand_throughput: {
max_read_request_units: 1,
max_write_request_units: 1,
},
global_table_source_arn: "TableArn",
global_table_settings_replication_mode: "ENABLED", # accepts ENABLED, DISABLED, ENABLED_WITH_OVERRIDES
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:attribute_definitions
(Array<Types::AttributeDefinition>)
—
An array of attributes that describe the key schema for the table and indexes.
-
:table_name
(required, String)
—
The name of the table to create. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.
-
:key_schema
(Array<Types::KeySchemaElement>)
—
Specifies the attributes that make up the primary key for a table or an index. The attributes in
KeySchemamust also be defined in theAttributeDefinitionsarray. For more information, see Data Model in the Amazon DynamoDB Developer Guide.Each
KeySchemaElementin the array is composed of:-
AttributeName- The name of this key attribute. -
KeyType- The role that the key attribute will assume: -
HASH- partition key -
RANGE- sort key
The partition key of an item is also known as its hash attribute. The term "hash attribute" derives from the DynamoDB usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values. The sort key of an item is also known as its range attribute. The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
For a simple primary key (partition key), you must provide exactly one element with a
KeyTypeofHASH.For a composite primary key (partition key and sort key), you must provide exactly two elements, in this order: The first element must have a
KeyTypeofHASH, and the second element must have aKeyTypeofRANGE.For more information, see Working with Tables in the Amazon DynamoDB Developer Guide.
-
-
:local_secondary_indexes
(Array<Types::LocalSecondaryIndex>)
—
One or more local secondary indexes (the maximum is 5) to be created on the table. Each index is scoped to a given partition key value. There is a 10 GB size limit per partition key value; otherwise, the size of a local secondary index is unconstrained.
Each local secondary index in the array includes the following:
-
IndexName- The name of the local secondary index. Must be unique only for this table. -
KeySchema- Specifies the key schema for the local secondary index. The key schema must begin with the same partition key as the table. -
Projection- Specifies attributes that are copied (projected) from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected. Each attribute specification is composed of: -
ProjectionType- One of the following:-
KEYS_ONLY- Only the index and primary keys are projected into the index. -
INCLUDE- Only the specified table attributes are projected into the index. The list of projected attributes is inNonKeyAttributes. -
ALL- All of the table attributes are projected into the index.
-
-
NonKeyAttributes- A list of one or more non-key attribute names that are projected into the secondary index. The total count of attributes provided inNonKeyAttributes, summed across all of the secondary indexes, must not exceed 100. If you project the same attribute into two different indexes, this counts as two distinct attributes when determining the total. This limit only applies when you specify the ProjectionType ofINCLUDE. You still can specify the ProjectionType ofALLto project all attributes from the source table, even if the table has more than 100 attributes.
-
-
:global_secondary_indexes
(Array<Types::GlobalSecondaryIndex>)
—
One or more global secondary indexes (the maximum is 20) to be created on the table. Each global secondary index in the array includes the following:
-
IndexName- The name of the global secondary index. Must be unique only for this table. -
KeySchema- Specifies the key schema for the global secondary index. Each global secondary index supports up to 4 partition keys and up to 4 sort keys. -
Projection- Specifies attributes that are copied (projected) from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected. Each attribute specification is composed of: -
ProjectionType- One of the following:-
KEYS_ONLY- Only the index and primary keys are projected into the index. -
INCLUDE- Only the specified table attributes are projected into the index. The list of projected attributes is inNonKeyAttributes. -
ALL- All of the table attributes are projected into the index.
-
-
NonKeyAttributes- A list of one or more non-key attribute names that are projected into the secondary index. The total count of attributes provided inNonKeyAttributes, summed across all of the secondary indexes, must not exceed 100. If you project the same attribute into two different indexes, this counts as two distinct attributes when determining the total. This limit only applies when you specify the ProjectionType ofINCLUDE. You still can specify the ProjectionType ofALLto project all attributes from the source table, even if the table has more than 100 attributes. -
ProvisionedThroughput- The provisioned throughput settings for the global secondary index, consisting of read and write capacity units.
-
-
:billing_mode
(String)
—
Controls how you are charged for read and write throughput and how you manage capacity. This setting can be changed later.
-
PAY_PER_REQUEST- We recommend usingPAY_PER_REQUESTfor most DynamoDB workloads.PAY_PER_REQUESTsets the billing mode to On-demand capacity mode. -
PROVISIONED- We recommend usingPROVISIONEDfor steady workloads with predictable growth where capacity requirements can be reliably forecasted.PROVISIONEDsets the billing mode to Provisioned capacity mode.
-
-
:provisioned_throughput
(Types::ProvisionedThroughput)
—
Represents the provisioned throughput settings for a specified table or index. The settings can be modified using the
UpdateTableoperation.If you set BillingMode as
PROVISIONED, you must specify this property. If you set BillingMode asPAY_PER_REQUEST, you cannot specify this property.For current minimum and maximum provisioned throughput values, see Service, Account, and Table Quotas in the Amazon DynamoDB Developer Guide.
-
:stream_specification
(Types::StreamSpecification)
—
The settings for DynamoDB Streams on the table. These settings consist of:
-
StreamEnabled- Indicates whether DynamoDB Streams is to be enabled (true) or disabled (false). -
StreamViewType- When an item in the table is modified,StreamViewTypedetermines what information is written to the table's stream. Valid values forStreamViewTypeare: -
KEYS_ONLY- Only the key attributes of the modified item are written to the stream. -
NEW_IMAGE- The entire item, as it appears after it was modified, is written to the stream. -
OLD_IMAGE- The entire item, as it appeared before it was modified, is written to the stream. -
NEW_AND_OLD_IMAGES- Both the new and the old item images of the item are written to the stream.
-
-
:sse_specification
(Types::SSESpecification)
—
Represents the settings used to enable server-side encryption.
-
:tags
(Array<Types::Tag>)
—
A list of key-value pairs to label the table. For more information, see Tagging for DynamoDB.
-
:table_class
(String)
—
The table class of the new table. Valid values are
STANDARDandSTANDARD_INFREQUENT_ACCESS. -
:deletion_protection_enabled
(Boolean)
—
Indicates whether deletion protection is to be enabled (true) or disabled (false) on the table.
-
:warm_throughput
(Types::WarmThroughput)
—
Represents the warm throughput (in read units per second and write units per second) for creating a table.
-
:resource_policy
(String)
—
An Amazon Web Services resource-based policy document in JSON format that will be attached to the table.
When you attach a resource-based policy while creating a table, the policy application is strongly consistent.
The maximum size supported for a resource-based policy document is 20 KB. DynamoDB counts whitespaces when calculating the size of a policy against this limit. For a full list of all considerations that apply for resource-based policies, see Resource-based policy considerations.
You need to specify the CreateTableandPutResourcePolicyIAM actions for authorizing a user to create a table with a resource-based policy. -
:on_demand_throughput
(Types::OnDemandThroughput)
—
Sets the maximum number of read and write units for the specified table in on-demand capacity mode. If you use this parameter, you must specify
MaxReadRequestUnits,MaxWriteRequestUnits, or both. -
:global_table_source_arn
(String)
—
The Amazon Resource Name (ARN) of the source table used for the creation of a multi-account global table.
-
:global_table_settings_replication_mode
(String)
—
Controls the settings synchronization mode for the global table. For multi-account global tables, this parameter is required and the only supported value is ENABLED. For same-account global tables, this parameter is set to ENABLED_WITH_OVERRIDES.
Returns:
- (Table)
120 |
# File 'sig/resource.rbs', line 120
def create_table: (
|
#tables(options = {}) ⇒ Table::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
dynamo_db.tables()
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Returns:
217 |
# File 'sig/resource.rbs', line 217
def tables: (
|