Class: Aws::DynamoDB::Types::CancellationReason

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

An ordered list of errors for each item in the request which caused the transaction to get cancelled. The values of the list are ordered according to the ordering of the TransactWriteItems request parameter. If no error occurred for the associated item an error with a Null code and Null message will be present.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

Status code for the result of the cancelled transaction.

Returns:

  • (String)


1212
1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-dynamodb/types.rb', line 1212

class CancellationReason < Struct.new(
  :item,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#itemHash<String,Types::AttributeValue>

Item in the request which caused the transaction to get cancelled.

Returns:



1212
1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-dynamodb/types.rb', line 1212

class CancellationReason < Struct.new(
  :item,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Cancellation reason message description.

Returns:

  • (String)


1212
1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-dynamodb/types.rb', line 1212

class CancellationReason < Struct.new(
  :item,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end