Class: Aws::DynamoDB::Types::ConsumedCapacity
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ConsumedCapacity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
The capacity units consumed by an operation. The data returned
includes the total provisioned throughput consumed, along with
statistics for the table and any indexes involved in the operation.
ConsumedCapacity is only returned if the request asked for it. For
more information, see Provisioned capacity mode in the Amazon
DynamoDB Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_units ⇒ Float
The total number of capacity units consumed by the operation.
-
#global_secondary_indexes ⇒ Hash<String,Types::Capacity>
The amount of throughput consumed on each global index affected by the operation.
-
#local_secondary_indexes ⇒ Hash<String,Types::Capacity>
The amount of throughput consumed on each local index affected by the operation.
-
#read_capacity_units ⇒ Float
The total number of read capacity units consumed by the operation.
-
#table ⇒ Types::Capacity
The amount of throughput consumed on the table affected by the operation.
-
#table_name ⇒ String
The name of the table that was affected by the operation.
-
#vector_indexes ⇒ Hash<String,Types::VectorCapacity>
The amount of throughput consumed on each vector index affected by the operation.
-
#write_capacity_units ⇒ Float
The total number of write capacity units consumed by the operation.
Instance Attribute Details
#capacity_units ⇒ Float
The total number of capacity units consumed by the operation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#global_secondary_indexes ⇒ Hash<String,Types::Capacity>
The amount of throughput consumed on each global index affected by the operation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#local_secondary_indexes ⇒ Hash<String,Types::Capacity>
The amount of throughput consumed on each local index affected by the operation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#read_capacity_units ⇒ Float
The total number of read capacity units consumed by the operation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#table ⇒ Types::Capacity
The amount of throughput consumed on the table affected by the operation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table that was affected by the operation. If you had specified the Amazon Resource Name (ARN) of a table in the input, you'll see the table ARN in the response.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#vector_indexes ⇒ Hash<String,Types::VectorCapacity>
The amount of throughput consumed on each vector index affected by
the operation. Each entry contains VectorWriteRequestBytes (for
write operations) or VectorSearchRequestBytes (for search
operations).
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#write_capacity_units ⇒ Float
The total number of write capacity units consumed by the operation.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1601 class ConsumedCapacity < Struct.new( :table_name, :capacity_units, :read_capacity_units, :write_capacity_units, :table, :local_secondary_indexes, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |