Class: Aws::DynamoDB::Types::ContributorInsightsSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ContributorInsightsSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents a Contributor Insights summary entry.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contributor_insights_mode ⇒ String
Indicates the current mode of CloudWatch Contributor Insights, specifying whether it tracks all access and throttled events or throttled events only for the DynamoDB table or index.
-
#contributor_insights_status ⇒ String
Describes the current status for contributor insights for the given table and index, if applicable.
-
#index_name ⇒ String
Name of the index associated with the summary, if any.
-
#table_name ⇒ String
Name of the table associated with the summary.
Instance Attribute Details
#contributor_insights_mode ⇒ String
Indicates the current mode of CloudWatch Contributor Insights, specifying whether it tracks all access and throttled events or throttled events only for the DynamoDB table or index.
1672 1673 1674 1675 1676 1677 1678 1679 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1672 class ContributorInsightsSummary < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#contributor_insights_status ⇒ String
Describes the current status for contributor insights for the given table and index, if applicable.
1672 1673 1674 1675 1676 1677 1678 1679 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1672 class ContributorInsightsSummary < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
Name of the index associated with the summary, if any.
1672 1673 1674 1675 1676 1677 1678 1679 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1672 class ContributorInsightsSummary < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
Name of the table associated with the summary.
1672 1673 1674 1675 1676 1677 1678 1679 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1672 class ContributorInsightsSummary < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |