Class: Aws::DynamoDB::Types::CreateReplicationGroupMemberAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::CreateReplicationGroupMemberAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents a replica to be created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_secondary_indexes ⇒ Array<Types::ReplicaGlobalSecondaryIndex>
Replica-specific global secondary index settings.
-
#kms_master_key_id ⇒ String
The KMS key that should be used for KMS encryption in the new replica.
-
#on_demand_throughput_override ⇒ Types::OnDemandThroughputOverride
The maximum on-demand throughput settings for the specified replica table being created.
-
#provisioned_throughput_override ⇒ Types::ProvisionedThroughputOverride
Replica-specific provisioned throughput.
-
#region_name ⇒ String
The Region where the new replica will be created.
-
#table_class_override ⇒ String
Replica-specific table class.
Instance Attribute Details
#global_secondary_indexes ⇒ Array<Types::ReplicaGlobalSecondaryIndex>
Replica-specific global secondary index settings.
1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1875 class CreateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#kms_master_key_id ⇒ String
The KMS key that should be used for KMS encryption in the new
replica. To specify a key, use its key ID, Amazon Resource Name
(ARN), alias name, or alias ARN. Note that you should only provide
this parameter if the key is different from the default DynamoDB KMS
key alias/aws/dynamodb.
1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1875 class CreateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#on_demand_throughput_override ⇒ Types::OnDemandThroughputOverride
The maximum on-demand throughput settings for the specified replica
table being created. You can only modify MaxReadRequestUnits,
because you can't modify MaxWriteRequestUnits for individual
replica tables.
1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1875 class CreateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#provisioned_throughput_override ⇒ Types::ProvisionedThroughputOverride
Replica-specific provisioned throughput. If not specified, uses the source table's provisioned throughput settings.
1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1875 class CreateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The Region where the new replica will be created.
1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1875 class CreateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#table_class_override ⇒ String
Replica-specific table class. If not specified, uses the source table's table class.
1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 1875 class CreateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |