Class: Aws::DynamoDB::Types::Delete

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents a request to perform a DeleteItem operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#condition_expressionString

A condition that must be satisfied in order for a conditional delete to succeed.



2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
# File 'lib/aws-sdk-dynamodb/types.rb', line 2337

class Delete < Struct.new(
  :key,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#expression_attribute_namesHash<String,String>

One or more substitution tokens for attribute names in an expression.



2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
# File 'lib/aws-sdk-dynamodb/types.rb', line 2337

class Delete < Struct.new(
  :key,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#expression_attribute_valuesHash<String,Types::AttributeValue>

One or more values that can be substituted in an expression.



2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
# File 'lib/aws-sdk-dynamodb/types.rb', line 2337

class Delete < Struct.new(
  :key,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#keyHash<String,Types::AttributeValue>

The primary key of the item to be deleted. Each element consists of an attribute name and a value for that attribute.



2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
# File 'lib/aws-sdk-dynamodb/types.rb', line 2337

class Delete < Struct.new(
  :key,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#return_values_on_condition_check_failureString

Use ReturnValuesOnConditionCheckFailure to get the item attributes if the Delete condition fails. For ReturnValuesOnConditionCheckFailure, the valid values are: NONE and ALL_OLD.



2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
# File 'lib/aws-sdk-dynamodb/types.rb', line 2337

class Delete < Struct.new(
  :key,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

Name of the table in which the item to be deleted resides. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.



2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
# File 'lib/aws-sdk-dynamodb/types.rb', line 2337

class Delete < Struct.new(
  :key,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end