Class: Aws::DynamoDB::Types::DeleteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents a request to perform a DeleteItem operation on an item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyHash<String,Types::AttributeValue>

A map of attribute name to attribute values, representing the primary key of the item to delete. All of the table's primary key attributes must be specified, and their data types must match those of the table's key schema.

Returns:



2725
2726
2727
2728
2729
# File 'lib/aws-sdk-dynamodb/types.rb', line 2725

class DeleteRequest < Struct.new(
  :key)
  SENSITIVE = []
  include Aws::Structure
end