Method: Aws::DynamoDB::Types::DeleteRequest#key
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
#key ⇒ Hash<String,Types::AttributeValue>
A map of attribute name to attribute values, representing the primary key of the item to delete. All of the table’s primary key attributes must be specified, and their data types must match those of the table’s key schema.
2636 2637 2638 2639 2640 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2636 class DeleteRequest < Struct.new( :key) SENSITIVE = [] include Aws::Structure end |