Class: Aws::DynamoDB::Types::DeleteResourcePolicyOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#revision_idString

A unique string that represents the revision ID of the policy. If you're comparing revision IDs, make sure to always use string comparison logic.

This value will be empty if you make a request against a resource without a policy.

Returns:

  • (String)


2768
2769
2770
2771
2772
# File 'lib/aws-sdk-dynamodb/types.rb', line 2768

class DeleteResourcePolicyOutput < Struct.new(
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end