Class: Aws::DynamoDB::Types::DescribeContributorInsightsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contributor_insights_modeString

The mode of CloudWatch Contributor Insights for DynamoDB that determines which events are emitted. Can be set to track all access and throttled events or throttled events only.



2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/aws-sdk-dynamodb/types.rb', line 2936

class DescribeContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_rule_list,
  :contributor_insights_status,
  :last_update_date_time,
  :failure_exception,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#contributor_insights_rule_listArray<String>

List of names of the associated contributor insights rules.



2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/aws-sdk-dynamodb/types.rb', line 2936

class DescribeContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_rule_list,
  :contributor_insights_status,
  :last_update_date_time,
  :failure_exception,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#contributor_insights_statusString

Current status of contributor insights.



2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/aws-sdk-dynamodb/types.rb', line 2936

class DescribeContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_rule_list,
  :contributor_insights_status,
  :last_update_date_time,
  :failure_exception,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#failure_exceptionTypes::FailureException

Returns information about the last failure that was encountered.

The most common exceptions for a FAILED status are:

  • LimitExceededException - Per-account Amazon CloudWatch Contributor Insights rule limit reached. Please disable Contributor Insights for other tables/indexes OR disable Contributor Insights rules before retrying.

  • AccessDeniedException - Amazon CloudWatch Contributor Insights rules cannot be modified due to insufficient permissions.

  • AccessDeniedException - Failed to create service-linked role for Contributor Insights due to insufficient permissions.

  • InternalServerError - Failed to create Amazon CloudWatch Contributor Insights rules. Please retry request.



2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/aws-sdk-dynamodb/types.rb', line 2936

class DescribeContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_rule_list,
  :contributor_insights_status,
  :last_update_date_time,
  :failure_exception,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the global secondary index being described.



2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/aws-sdk-dynamodb/types.rb', line 2936

class DescribeContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_rule_list,
  :contributor_insights_status,
  :last_update_date_time,
  :failure_exception,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_date_timeTime

Timestamp of the last time the status was changed.



2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/aws-sdk-dynamodb/types.rb', line 2936

class DescribeContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_rule_list,
  :contributor_insights_status,
  :last_update_date_time,
  :failure_exception,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table being described.



2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
# File 'lib/aws-sdk-dynamodb/types.rb', line 2936

class DescribeContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_rule_list,
  :contributor_insights_status,
  :last_update_date_time,
  :failure_exception,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end