Class: Aws::DynamoDB::Types::DescribeImportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::DescribeImportOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#import_table_description ⇒ Types::ImportTableDescription
Represents the properties of the table created for the import, and parameters of the import.
Instance Attribute Details
#import_table_description ⇒ Types::ImportTableDescription
Represents the properties of the table created for the import, and parameters of the import. The import parameters include import status, how many items were processed, and how many errors were encountered.
3065 3066 3067 3068 3069 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3065 class DescribeImportOutput < Struct.new( :import_table_description) SENSITIVE = [] include Aws::Structure end |