Class: Aws::DynamoDB::Types::ExportDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents the properties of the exported table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billed_size_bytesInteger

The billable size of the table export.

Returns:

  • (Integer)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

The client token that was provided for the export task. A client token makes calls to ExportTableToPointInTimeInput idempotent, meaning that multiple identical calls have the same effect as one single call.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time at which the export task completed.

Returns:

  • (Time)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#export_arnString

The Amazon Resource Name (ARN) of the table export.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#export_formatString

The format of the exported data. Valid values for ExportFormat are DYNAMODB_JSON or ION.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#export_manifestString

The name of the manifest file for the export task.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#export_statusString

Export can be in one of the following states: IN_PROGRESS, COMPLETED, or FAILED.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#export_timeTime

Point in time from which table data was exported.

Returns:

  • (Time)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#export_typeString

The type of export that was performed. Valid values are FULL_EXPORT or INCREMENTAL_EXPORT.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

Status code for the result of the failed export.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

Export failure reason description.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#incremental_export_specificationTypes::IncrementalExportSpecification

Optional object containing the parameters specific to an incremental export.



3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#item_countInteger

The number of items exported.

Returns:

  • (Integer)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucketString

The name of the Amazon S3 bucket containing the export.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_ownerString

The ID of the Amazon Web Services account that owns the bucket containing the export.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_prefixString

The Amazon S3 bucket prefix used as the file name and path of the exported snapshot.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_sse_algorithmString

Type of encryption used on the bucket where export data is stored. Valid values for S3SseAlgorithm are:

  • AES256 - server-side encryption with Amazon S3 managed keys

  • KMS - server-side encryption with KMS managed keys

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_sse_kms_key_idString

The ID of the KMS managed key used to encrypt the S3 bucket where export data is stored (if applicable).

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time at which the export task began.

Returns:

  • (Time)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#table_arnString

The Amazon Resource Name (ARN) of the table that was exported.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end

#table_idString

Unique ID of the table that was exported.

Returns:

  • (String)


3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830

class ExportDescription < Struct.new(
  :export_arn,
  :export_status,
  :start_time,
  :end_time,
  :export_manifest,
  :table_arn,
  :table_id,
  :export_time,
  :client_token,
  :s3_bucket,
  :s3_bucket_owner,
  :s3_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :failure_code,
  :failure_message,
  :export_format,
  :billed_size_bytes,
  :item_count,
  :export_type,
  :incremental_export_specification)
  SENSITIVE = []
  include Aws::Structure
end