Class: Aws::DynamoDB::Types::Get
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::Get
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Specifies an item and related attribute values to retrieve in a
TransactGetItem object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expression_attribute_names ⇒ Hash<String,String>
One or more substitution tokens for attribute names in the ProjectionExpression parameter.
-
#key ⇒ Hash<String,Types::AttributeValue>
A map of attribute names to
AttributeValueobjects that specifies the primary key of the item to retrieve. -
#projection_expression ⇒ String
A string that identifies one or more attributes of the specified item to retrieve from the table.
-
#table_name ⇒ String
The name of the table from which to retrieve the specified item.
Instance Attribute Details
#expression_attribute_names ⇒ Hash<String,String>
One or more substitution tokens for attribute names in the ProjectionExpression parameter.
4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4053 class Get < Struct.new( :key, :table_name, :projection_expression, :expression_attribute_names) SENSITIVE = [] include Aws::Structure end |
#key ⇒ Hash<String,Types::AttributeValue>
A map of attribute names to AttributeValue objects that specifies
the primary key of the item to retrieve.
4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4053 class Get < Struct.new( :key, :table_name, :projection_expression, :expression_attribute_names) SENSITIVE = [] include Aws::Structure end |
#projection_expression ⇒ String
A string that identifies one or more attributes of the specified item to retrieve from the table. The attributes in the expression must be separated by commas. If no attribute names are specified, then all attributes of the specified item are returned. If any of the requested attributes are not found, they do not appear in the result.
4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4053 class Get < Struct.new( :key, :table_name, :projection_expression, :expression_attribute_names) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table from which to retrieve the specified item. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.
4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4053 class Get < Struct.new( :key, :table_name, :projection_expression, :expression_attribute_names) SENSITIVE = [] include Aws::Structure end |