Class: Aws::DynamoDB::Types::GetItemOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents the output of a GetItem operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumed_capacityTypes::ConsumedCapacity

The capacity units consumed by the GetItem operation. The data returned includes the total provisioned throughput consumed, along with statistics for the table and any indexes involved in the operation. ConsumedCapacity is only returned if the ReturnConsumedCapacity parameter was specified. For more information, see Capacity unit consumption for read operations in the Amazon DynamoDB Developer Guide.



4224
4225
4226
4227
4228
4229
# File 'lib/aws-sdk-dynamodb/types.rb', line 4224

class GetItemOutput < Struct.new(
  :item,
  :consumed_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#itemHash<String,Types::AttributeValue>

A map of attribute names to AttributeValue objects, as specified by ProjectionExpression.

Returns:



4224
4225
4226
4227
4228
4229
# File 'lib/aws-sdk-dynamodb/types.rb', line 4224

class GetItemOutput < Struct.new(
  :item,
  :consumed_capacity)
  SENSITIVE = []
  include Aws::Structure
end