Class: Aws::DynamoDB::Types::GlobalSecondaryIndexUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents one of the following:

  • A new global secondary index to be added to an existing table.

  • New provisioned throughput parameters for an existing global secondary index.

  • An existing global secondary index to be removed from an existing table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#createTypes::CreateGlobalSecondaryIndexAction

The parameters required for creating a global secondary index on an existing table:

  • IndexName

  • KeySchema

  • AttributeDefinitions

  • Projection

  • ProvisionedThroughput



4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-dynamodb/types.rb', line 4583

class GlobalSecondaryIndexUpdate < Struct.new(
  :update,
  :create,
  :delete)
  SENSITIVE = []
  include Aws::Structure
end

#deleteTypes::DeleteGlobalSecondaryIndexAction

The name of an existing global secondary index to be removed.



4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-dynamodb/types.rb', line 4583

class GlobalSecondaryIndexUpdate < Struct.new(
  :update,
  :create,
  :delete)
  SENSITIVE = []
  include Aws::Structure
end

#updateTypes::UpdateGlobalSecondaryIndexAction

The name of an existing global secondary index, along with new provisioned throughput settings to be applied to that index.



4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-dynamodb/types.rb', line 4583

class GlobalSecondaryIndexUpdate < Struct.new(
  :update,
  :create,
  :delete)
  SENSITIVE = []
  include Aws::Structure
end