Class: Aws::DynamoDB::Types::ImportSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Summary information about the source file for the import.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_log_group_arnString

The Amazon Resource Number (ARN) of the Cloudwatch Log Group associated with this import task.

Returns:

  • (String)


4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time at which this import task ended. (Does this include the successful complete creation of the table it was imported to?)

Returns:

  • (Time)


4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#import_arnString

The Amazon Resource Number (ARN) corresponding to the import request.

Returns:

  • (String)


4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#import_statusString

The status of the import operation.

Returns:

  • (String)


4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#input_formatString

The format of the source data. Valid values are CSV, DYNAMODB_JSON or ION.

Returns:

  • (String)


4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_sourceTypes::S3BucketSource

The path and S3 bucket of the source file that is being imported. This includes the S3Bucket (required), S3KeyPrefix (optional) and S3BucketOwner (optional if the bucket is owned by the requester).



4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time at which this import task began.

Returns:

  • (Time)


4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#table_arnString

The Amazon Resource Number (ARN) of the table being imported into.

Returns:

  • (String)


4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/aws-sdk-dynamodb/types.rb', line 4765

class ImportSummary < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :s3_bucket_source,
  :cloud_watch_log_group_arn,
  :input_format,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end