Class: Aws::DynamoDB::Types::ImportTableDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents the properties of the table being imported into.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The client token that was provided for the import task. Reusing the client token on retry makes a call to ImportTable idempotent.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_watch_log_group_arnString

The Amazon Resource Number (ARN) of the Cloudwatch Log Group associated with the target table.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time at which the creation of the table associated with this import task completed.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#error_countInteger

The number of errors occurred on importing the source file into the target table.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

The error code corresponding to the failure that the import job ran into during execution.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

The error message corresponding to the failure that the import job ran into during execution.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#import_arnString

The Amazon Resource Number (ARN) corresponding to the import request.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#import_statusString

The status of the import.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#imported_item_countInteger

The number of items successfully imported into the new table.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#input_compression_typeString

The compression options for the data that has been imported into the target table. The values are NONE, GZIP, or ZSTD.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#input_formatString

The format of the source data going into the target table.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#input_format_optionsTypes::InputFormatOptions

The format options for the data that was imported into the target table. There is one value, CsvOption.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#processed_item_countInteger

The total number of items processed from the source file.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#processed_size_bytesInteger

The total size of data processed from the source file, in Bytes.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_sourceTypes::S3BucketSource

Values for the S3 bucket the source file is imported from. Includes bucket name (required), key prefix (optional) and bucket account owner ID (optional).

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time when this import task started.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#table_arnString

The Amazon Resource Number (ARN) of the table being imported into.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#table_creation_parametersTypes::TableCreationParameters

The parameters for the new table that is being imported into.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#table_idString

The table id corresponding to the table created by import table process.

Returns:



4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
# File 'lib/aws-sdk-dynamodb/types.rb', line 4870

class ImportTableDescription < Struct.new(
  :import_arn,
  :import_status,
  :table_arn,
  :table_id,
  :client_token,
  :s3_bucket_source,
  :error_count,
  :cloud_watch_log_group_arn,
  :input_format,
  :input_format_options,
  :input_compression_type,
  :table_creation_parameters,
  :start_time,
  :end_time,
  :processed_size_bytes,
  :processed_item_count,
  :imported_item_count,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end