Class: Aws::DynamoDB::Types::IncrementalExportSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Optional object containing the parameters specific to an incremental export.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_from_timeTime

Time in the past which provides the inclusive start range for the export table's data, counted in seconds from the start of the Unix epoch. The incremental export will reflect the table's state including and after this point in time.

Returns:

  • (Time)


5103
5104
5105
5106
5107
5108
5109
# File 'lib/aws-sdk-dynamodb/types.rb', line 5103

class IncrementalExportSpecification < Struct.new(
  :export_from_time,
  :export_to_time,
  :export_view_type)
  SENSITIVE = []
  include Aws::Structure
end

#export_to_timeTime

Time in the past which provides the exclusive end range for the export table's data, counted in seconds from the start of the Unix epoch. The incremental export will reflect the table's state just prior to this point in time. If this is not provided, the latest time with data available will be used.

Returns:

  • (Time)


5103
5104
5105
5106
5107
5108
5109
# File 'lib/aws-sdk-dynamodb/types.rb', line 5103

class IncrementalExportSpecification < Struct.new(
  :export_from_time,
  :export_to_time,
  :export_view_type)
  SENSITIVE = []
  include Aws::Structure
end

#export_view_typeString

The view type that was chosen for the export. Valid values are NEW_AND_OLD_IMAGES and NEW_IMAGES. The default value is NEW_AND_OLD_IMAGES.

NEW_AND_OLD_IMAGES exports both the new and old images of each changed item, while NEW_IMAGES exports only the new (latest) image. The view type you choose determines the structure of each item in the output for insert, update, and delete operations. For details and examples of how each view type shapes the export output, see DynamoDB table export output format in the Amazon DynamoDB Developer Guide.

Returns:

  • (String)


5103
5104
5105
5106
5107
5108
5109
# File 'lib/aws-sdk-dynamodb/types.rb', line 5103

class IncrementalExportSpecification < Struct.new(
  :export_from_time,
  :export_to_time,
  :export_view_type)
  SENSITIVE = []
  include Aws::Structure
end