Class: Aws::DynamoDB::Types::ListGlobalTablesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ListGlobalTablesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclusive_start_global_table_name ⇒ String
The first global table name that this operation will evaluate.
-
#limit ⇒ Integer
The maximum number of table names to return, if the parameter is not specified DynamoDB defaults to 100.
-
#region_name ⇒ String
Lists the global tables in a specific Region.
Instance Attribute Details
#exclusive_start_global_table_name ⇒ String
The first global table name that this operation will evaluate.
5708 5709 5710 5711 5712 5713 5714 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 5708 class ListGlobalTablesInput < Struct.new( :exclusive_start_global_table_name, :limit, :region_name) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of table names to return, if the parameter is not specified DynamoDB defaults to 100.
If the number of global tables DynamoDB finds reaches this limit, it
stops the operation and returns the table names collected up to that
point, with a table name in the LastEvaluatedGlobalTableName to
apply in a subsequent operation to the
ExclusiveStartGlobalTableName parameter.
5708 5709 5710 5711 5712 5713 5714 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 5708 class ListGlobalTablesInput < Struct.new( :exclusive_start_global_table_name, :limit, :region_name) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
Lists the global tables in a specific Region.
5708 5709 5710 5711 5712 5713 5714 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 5708 class ListGlobalTablesInput < Struct.new( :exclusive_start_global_table_name, :limit, :region_name) SENSITIVE = [] include Aws::Structure end |