Class: Aws::DynamoDB::Types::LocalSecondaryIndexInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents the properties of a local secondary index for the table when the backup was created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#index_nameString

Represents the name of the local secondary index.

Returns:

  • (String)


6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-dynamodb/types.rb', line 6013

class LocalSecondaryIndexInfo < Struct.new(
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#key_schemaArray<Types::KeySchemaElement>

The complete key schema for a local secondary index, which consists of one or more pairs of attribute names and key types:

  • HASH - partition key

  • RANGE - sort key

The partition key of an item is also known as its hash attribute. The term "hash attribute" derives from DynamoDB's usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values.

The sort key of an item is also known as its range attribute. The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.

Returns:



6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-dynamodb/types.rb', line 6013

class LocalSecondaryIndexInfo < Struct.new(
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end

#projectionTypes::Projection

Represents attributes that are copied (projected) from the table into the global secondary index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.

Returns:



6013
6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-dynamodb/types.rb', line 6013

class LocalSecondaryIndexInfo < Struct.new(
  :index_name,
  :key_schema,
  :projection)
  SENSITIVE = []
  include Aws::Structure
end