Class: Aws::DynamoDB::Types::ProvisionedThroughputDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ProvisionedThroughputDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents the provisioned throughput settings for the table, consisting of read and write capacity units, along with data about increases and decreases.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_decrease_date_time ⇒ Time
The date and time of the last provisioned throughput decrease for this table.
-
#last_increase_date_time ⇒ Time
The date and time of the last provisioned throughput increase for this table.
-
#number_of_decreases_today ⇒ Integer
The number of provisioned throughput decreases for this table during this UTC calendar day.
-
#read_capacity_units ⇒ Integer
The maximum number of strongly consistent reads consumed per second before DynamoDB returns a
ThrottlingException. -
#write_capacity_units ⇒ Integer
The maximum number of writes consumed per second before DynamoDB returns a
ThrottlingException.
Instance Attribute Details
#last_decrease_date_time ⇒ Time
The date and time of the last provisioned throughput decrease for this table.
6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6330 class ProvisionedThroughputDescription < Struct.new( :last_increase_date_time, :last_decrease_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#last_increase_date_time ⇒ Time
The date and time of the last provisioned throughput increase for this table.
6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6330 class ProvisionedThroughputDescription < Struct.new( :last_increase_date_time, :last_decrease_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#number_of_decreases_today ⇒ Integer
The number of provisioned throughput decreases for this table during this UTC calendar day. For current maximums on provisioned throughput decreases, see Service, Account, and Table Quotas in the Amazon DynamoDB Developer Guide.
6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6330 class ProvisionedThroughputDescription < Struct.new( :last_increase_date_time, :last_decrease_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#read_capacity_units ⇒ Integer
The maximum number of strongly consistent reads consumed per second
before DynamoDB returns a ThrottlingException. Eventually
consistent reads require less effort than strongly consistent reads,
so a setting of 50 ReadCapacityUnits per second provides 100
eventually consistent ReadCapacityUnits per second.
For a table or global secondary index that uses on-demand capacity
mode (PAY_PER_REQUEST), this value is 0, because on-demand mode
does not use provisioned throughput.
6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6330 class ProvisionedThroughputDescription < Struct.new( :last_increase_date_time, :last_decrease_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |
#write_capacity_units ⇒ Integer
The maximum number of writes consumed per second before DynamoDB
returns a ThrottlingException.
For a table or global secondary index that uses on-demand capacity
mode (PAY_PER_REQUEST), this value is 0, because on-demand mode
does not use provisioned throughput.
6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6330 class ProvisionedThroughputDescription < Struct.new( :last_increase_date_time, :last_decrease_date_time, :number_of_decreases_today, :read_capacity_units, :write_capacity_units) SENSITIVE = [] include Aws::Structure end |