Class: Aws::DynamoDB::Types::ProvisionedThroughputExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ProvisionedThroughputExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
The request was denied due to request throttling. For detailed information about why the request was throttled and the ARN of the impacted resource, find the ThrottlingReason field in the returned exception. The Amazon Web Services SDKs for DynamoDB automatically retry requests that receive this exception. Your request is eventually successful, unless your retry queue is too large to finish. Reduce the frequency of requests and use exponential backoff. For more information, go to Error Retries and Exponential Backoff in the Amazon DynamoDB Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
You exceeded your maximum allowed provisioned throughput.
-
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of [ThrottlingReason][1] that provide detailed diagnostic information about why the request was throttled.
Instance Attribute Details
#message ⇒ String
You exceeded your maximum allowed provisioned throughput.
6370 6371 6372 6373 6374 6375 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6370 class ProvisionedThroughputExceededException < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of ThrottlingReason that provide detailed diagnostic information about why the request was throttled.
6370 6371 6372 6373 6374 6375 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6370 class ProvisionedThroughputExceededException < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |