Method: Aws::DynamoDB::Types::PutItemInput#item
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
#item ⇒ Hash<String,Types::AttributeValue>
A map of attribute name/value pairs, one for each attribute. Only the primary key attributes are required; you can optionally provide other attribute name-value pairs for the item.
You must provide all of the attributes for the primary key. For example, with a simple primary key, you only need to provide a value for the partition key. For a composite primary key, you must provide both values for both the partition key and the sort key.
If you specify any attributes that are part of an index key, then the data types for those attributes must match those of the schema in the table’s attribute definition.
Empty String and Binary attribute values are allowed. Attribute values of type String and Binary must have a length greater than zero if the attribute is used as a key attribute for a table or index.
For more information about primary keys, see [Primary Key] in the *Amazon DynamoDB Developer Guide*.
Each element in the Item map is an AttributeValue object.
6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6545 class PutItemInput < Struct.new( :table_name, :item, :expected, :return_values, :return_consumed_capacity, :return_item_collection_metrics, :conditional_operator, :condition_expression, :expression_attribute_names, :expression_attribute_values, :return_values_on_condition_check_failure) SENSITIVE = [] include Aws::Structure end |