Class: Aws::DynamoDB::Types::RequestLimitExceeded

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Throughput exceeds the current throughput quota for your account. For detailed information about why the request was throttled and the ARN of the impacted resource, find the [ThrottlingReason][1] field in the returned exception. Contact [Amazon Web Services Support][2] to request a quota increase.

[1]: docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ThrottlingReason.html [2]: aws.amazon.com/support

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:



7868
7869
7870
7871
7872
7873
# File 'lib/aws-sdk-dynamodb/types.rb', line 7868

class RequestLimitExceeded < Struct.new(
  :message,
  :throttling_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#throttling_reasonsArray<Types::ThrottlingReason>

A list of [ThrottlingReason][1] that provide detailed diagnostic information about why the request was throttled.

[1]: docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ThrottlingReason.html

Returns:



7868
7869
7870
7871
7872
7873
# File 'lib/aws-sdk-dynamodb/types.rb', line 7868

class RequestLimitExceeded < Struct.new(
  :message,
  :throttling_reasons)
  SENSITIVE = []
  include Aws::Structure
end