Class: Aws::DynamoDB::Types::RestoreTableFromBackupInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_arnString

The Amazon Resource Name (ARN) associated with the backup.

Returns:

  • (String)


8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#billing_mode_overrideString

The billing mode of the restored table.

Returns:

  • (String)


8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#global_secondary_index_overrideArray<Types::GlobalSecondaryIndex>

List of global secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.

Returns:



8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#local_secondary_index_overrideArray<Types::LocalSecondaryIndex>

List of local secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.

Returns:



8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#on_demand_throughput_overrideTypes::OnDemandThroughput

Sets the maximum number of read and write units for the specified on-demand table. If you use this parameter, you must specify MaxReadRequestUnits, MaxWriteRequestUnits, or both.



8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_throughput_overrideTypes::ProvisionedThroughput

Provisioned throughput settings for the restored table.



8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specification_overrideTypes::SSESpecification

The new server-side encryption settings for the restored table.



8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#target_table_nameString

The name of the new table to which the backup must be restored.

Returns:

  • (String)


8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end

#vector_index_overrideArray<Types::VectorIndex>

The vector indexes for the restored table. If not specified, all vector indexes from the backup are restored. The indexes provided must match existing vector indexes from the backup. You can choose to exclude some or all of the vector indexes at the time of restore.

Returns:



8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131

class RestoreTableFromBackupInput < Struct.new(
  :target_table_name,
  :backup_arn,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override,
  :vector_index_override)
  SENSITIVE = []
  include Aws::Structure
end