Class: Aws::DynamoDB::Types::RestoreTableToPointInTimeInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_mode_overrideString

The billing mode of the restored table.

Returns:

  • (String)


8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#global_secondary_index_overrideArray<Types::GlobalSecondaryIndex>

List of global secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.

Returns:



8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#local_secondary_index_overrideArray<Types::LocalSecondaryIndex>

List of local secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.

Returns:



8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#on_demand_throughput_overrideTypes::OnDemandThroughput

Sets the maximum number of read and write units for the specified on-demand table. If you use this parameter, you must specify MaxReadRequestUnits, MaxWriteRequestUnits, or both.



8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_throughput_overrideTypes::ProvisionedThroughput

Provisioned throughput settings for the restored table.



8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#restore_date_timeTime

Time in the past to restore the table to.

Returns:

  • (Time)


8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_arnString

The DynamoDB table that will be restored. This value is an Amazon Resource Name (ARN).

Returns:

  • (String)


8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_nameString

Name of the source table that is being restored.

Returns:

  • (String)


8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specification_overrideTypes::SSESpecification

The new server-side encryption settings for the restored table.



8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#target_table_nameString

The name of the new table to which it must be restored to.

Returns:

  • (String)


8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end

#use_latest_restorable_timeBoolean

Restore the table to the latest possible time. LatestRestorableDateTime is typically 5 minutes before the current time.

Returns:

  • (Boolean)


8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
# File 'lib/aws-sdk-dynamodb/types.rb', line 8065

class RestoreTableToPointInTimeInput < Struct.new(
  :source_table_arn,
  :source_table_name,
  :target_table_name,
  :use_latest_restorable_time,
  :restore_date_time,
  :billing_mode_override,
  :global_secondary_index_override,
  :local_secondary_index_override,
  :provisioned_throughput_override,
  :on_demand_throughput_override,
  :sse_specification_override)
  SENSITIVE = []
  include Aws::Structure
end