Class: Aws::DynamoDB::Types::SearchResultItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

A single result from a SearchVectors operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemHash<String,Types::AttributeValue>

A map of attribute names to AttributeValue objects, representing the projected attributes of the item returned by the vector search.

Returns:



8800
8801
8802
8803
8804
8805
# File 'lib/aws-sdk-dynamodb/types.rb', line 8800

class SearchResultItem < Struct.new(
  :item,
  :score)
  SENSITIVE = []
  include Aws::Structure
end

#scoreFloat

The similarity score for this item relative to the search vector. The interpretation depends on the distance function configured for the vector index.

Returns:

  • (Float)


8800
8801
8802
8803
8804
8805
# File 'lib/aws-sdk-dynamodb/types.rb', line 8800

class SearchResultItem < Struct.new(
  :item,
  :score)
  SENSITIVE = []
  include Aws::Structure
end