Class: Aws::DynamoDB::Types::SearchVectorsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumed_capacityTypes::VectorCapacity

The capacity units consumed by the SearchVectors operation. Contains VectorSearchRequestBytes, which represents the vector search capacity consumed.



8937
8938
8939
8940
8941
8942
# File 'lib/aws-sdk-dynamodb/types.rb', line 8937

class SearchVectorsOutput < Struct.new(
  :consumed_capacity,
  :search_results)
  SENSITIVE = []
  include Aws::Structure
end

#search_resultsArray<Types::SearchResultItem>

A list of items returned by the vector similarity search, sorted by similarity with the most similar item first. Each item contains the projected attributes and a similarity score.

Returns:



8937
8938
8939
8940
8941
8942
# File 'lib/aws-sdk-dynamodb/types.rb', line 8937

class SearchVectorsOutput < Struct.new(
  :consumed_capacity,
  :search_results)
  SENSITIVE = []
  include Aws::Structure
end