Class: Aws::DynamoDB::Types::SourceTableFeatureDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::SourceTableFeatureDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Contains the details of the features enabled on the table when the backup was created. For example, LSIs, GSIs, streams, TTL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_secondary_indexes ⇒ Array<Types::GlobalSecondaryIndexInfo>
Represents the GSI properties for the table when the backup was created.
-
#local_secondary_indexes ⇒ Array<Types::LocalSecondaryIndexInfo>
Represents the LSI properties for the table when the backup was created.
-
#sse_description ⇒ Types::SSEDescription
The description of the server-side encryption status on the table when the backup was created.
-
#stream_description ⇒ Types::StreamSpecification
Stream settings on the table when the backup was created.
-
#time_to_live_description ⇒ Types::TimeToLiveDescription
Time to Live settings on the table when the backup was created.
-
#vector_indexes ⇒ Array<Types::VectorIndexInfo>
The vector index properties for the table at the time the backup was created, including the index name, vector attribute, dimensions, distance function, search schema, and projection.
Instance Attribute Details
#global_secondary_indexes ⇒ Array<Types::GlobalSecondaryIndexInfo>
Represents the GSI properties for the table when the backup was created. It includes the IndexName, KeySchema, Projection, and ProvisionedThroughput for the GSIs on the table at the time of backup.
9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9052 class SourceTableFeatureDetails < Struct.new( :local_secondary_indexes, :global_secondary_indexes, :stream_description, :time_to_live_description, :sse_description, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#local_secondary_indexes ⇒ Array<Types::LocalSecondaryIndexInfo>
Represents the LSI properties for the table when the backup was created. It includes the IndexName, KeySchema and Projection for the LSIs on the table at the time of backup.
9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9052 class SourceTableFeatureDetails < Struct.new( :local_secondary_indexes, :global_secondary_indexes, :stream_description, :time_to_live_description, :sse_description, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#sse_description ⇒ Types::SSEDescription
The description of the server-side encryption status on the table when the backup was created.
9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9052 class SourceTableFeatureDetails < Struct.new( :local_secondary_indexes, :global_secondary_indexes, :stream_description, :time_to_live_description, :sse_description, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#stream_description ⇒ Types::StreamSpecification
Stream settings on the table when the backup was created.
9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9052 class SourceTableFeatureDetails < Struct.new( :local_secondary_indexes, :global_secondary_indexes, :stream_description, :time_to_live_description, :sse_description, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#time_to_live_description ⇒ Types::TimeToLiveDescription
Time to Live settings on the table when the backup was created.
9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9052 class SourceTableFeatureDetails < Struct.new( :local_secondary_indexes, :global_secondary_indexes, :stream_description, :time_to_live_description, :sse_description, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#vector_indexes ⇒ Array<Types::VectorIndexInfo>
The vector index properties for the table at the time the backup was created, including the index name, vector attribute, dimensions, distance function, search schema, and projection.
9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9052 class SourceTableFeatureDetails < Struct.new( :local_secondary_indexes, :global_secondary_indexes, :stream_description, :time_to_live_description, :sse_description, :vector_indexes) SENSITIVE = [] include Aws::Structure end |