Class: Aws::DynamoDB::Types::TableCreationParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

The parameters for the table created as part of the import operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_definitionsArray<Types::AttributeDefinition>

The attributes of the table created as part of the import operation.

Returns:



9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#billing_modeString

The billing mode for provisioning the table created as part of the import operation.

Returns:

  • (String)


9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#global_secondary_indexesArray<Types::GlobalSecondaryIndex>

The Global Secondary Indexes (GSI) of the table to be created as part of the import operation.

Returns:



9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#key_schemaArray<Types::KeySchemaElement>

The primary key and option sort key of the table created as part of the import operation.

Returns:



9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#on_demand_throughputTypes::OnDemandThroughput

Sets the maximum number of read and write units for the specified on-demand table. If you use this parameter, you must specify MaxReadRequestUnits, MaxWriteRequestUnits, or both.



9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_throughputTypes::ProvisionedThroughput

Represents the provisioned throughput settings for the specified global secondary index. You must use ProvisionedThroughput or OnDemandThroughput based on your table’s capacity mode.

For current minimum and maximum provisioned throughput values, see Service, Account, and Table Quotas in the Amazon DynamoDB Developer Guide.



9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#sse_specificationTypes::SSESpecification

Represents the settings used to enable server-side encryption.



9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table created as part of the import operation.

Returns:

  • (String)


9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end

#vector_indexesArray<Types::VectorIndex>

The vector indexes of the table to be created as part of the import operation.

Returns:



9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218

class TableCreationParameters < Struct.new(
  :table_name,
  :attribute_definitions,
  :key_schema,
  :billing_mode,
  :provisioned_throughput,
  :on_demand_throughput,
  :sse_specification,
  :global_secondary_indexes,
  :vector_indexes)
  SENSITIVE = []
  include Aws::Structure
end