Class: Aws::DynamoDB::Types::TableWarmThroughputDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::TableWarmThroughputDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents the warm throughput value (in read units per second and write units per second) of the table. Warm throughput is applicable for DynamoDB Standard-IA tables and specifies the minimum provisioned capacity maintained for immediate data access.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#read_units_per_second ⇒ Integer
Represents the base table’s warm throughput value in read units per second.
-
#status ⇒ String
Represents warm throughput value of the base table.
-
#write_units_per_second ⇒ Integer
Represents the base table’s warm throughput value in write units per second.
Instance Attribute Details
#read_units_per_second ⇒ Integer
Represents the base table’s warm throughput value in read units per second.
9333 9334 9335 9336 9337 9338 9339 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9333 class TableWarmThroughputDescription < Struct.new( :read_units_per_second, :write_units_per_second, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Represents warm throughput value of the base table.
9333 9334 9335 9336 9337 9338 9339 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9333 class TableWarmThroughputDescription < Struct.new( :read_units_per_second, :write_units_per_second, :status) SENSITIVE = [] include Aws::Structure end |
#write_units_per_second ⇒ Integer
Represents the base table’s warm throughput value in write units per second.
9333 9334 9335 9336 9337 9338 9339 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9333 class TableWarmThroughputDescription < Struct.new( :read_units_per_second, :write_units_per_second, :status) SENSITIVE = [] include Aws::Structure end |