Class: Aws::DynamoDB::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

The request was denied due to request throttling. For detailed information about why the request was throttled and the ARN of the impacted resource, find the ThrottlingReason field in the returned exception.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


9792
9793
9794
9795
9796
9797
# File 'lib/aws-sdk-dynamodb/types.rb', line 9792

class ThrottlingException < Struct.new(
  :message,
  :throttling_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#throttling_reasonsArray<Types::ThrottlingReason>

A list of ThrottlingReason that provide detailed diagnostic information about why the request was throttled.

Returns:



9792
9793
9794
9795
9796
9797
# File 'lib/aws-sdk-dynamodb/types.rb', line 9792

class ThrottlingException < Struct.new(
  :message,
  :throttling_reasons)
  SENSITIVE = []
  include Aws::Structure
end