Class: Aws::DynamoDB::Types::TransactWriteItemsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumed_capacityArray<Types::ConsumedCapacity>

The capacity units consumed by the entire TransactWriteItems operation. The values of the list are ordered according to the ordering of the TransactItems request parameter.



9718
9719
9720
9721
9722
9723
# File 'lib/aws-sdk-dynamodb/types.rb', line 9718

class TransactWriteItemsOutput < Struct.new(
  :consumed_capacity,
  :item_collection_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#item_collection_metricsHash<String,Array<Types::ItemCollectionMetrics>>

A list of tables that were processed by TransactWriteItems and, for each table, information about any item collections that were affected by individual UpdateItem, PutItem, or DeleteItem operations.



9718
9719
9720
9721
9722
9723
# File 'lib/aws-sdk-dynamodb/types.rb', line 9718

class TransactWriteItemsOutput < Struct.new(
  :consumed_capacity,
  :item_collection_metrics)
  SENSITIVE = []
  include Aws::Structure
end