Class: Aws::DynamoDB::Types::Update

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Represents a request to perform an UpdateItem operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#condition_expressionString

A condition that must be satisfied in order for a conditional update to succeed.



10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
# File 'lib/aws-sdk-dynamodb/types.rb', line 10408

class Update < Struct.new(
  :key,
  :update_expression,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#expression_attribute_namesHash<String,String>

One or more substitution tokens for attribute names in an expression.



10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
# File 'lib/aws-sdk-dynamodb/types.rb', line 10408

class Update < Struct.new(
  :key,
  :update_expression,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#expression_attribute_valuesHash<String,Types::AttributeValue>

One or more values that can be substituted in an expression.



10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
# File 'lib/aws-sdk-dynamodb/types.rb', line 10408

class Update < Struct.new(
  :key,
  :update_expression,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#keyHash<String,Types::AttributeValue>

The primary key of the item to be updated. Each element consists of an attribute name and a value for that attribute.



10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
# File 'lib/aws-sdk-dynamodb/types.rb', line 10408

class Update < Struct.new(
  :key,
  :update_expression,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#return_values_on_condition_check_failureString

Use ReturnValuesOnConditionCheckFailure to get the item attributes if the Update condition fails. For ReturnValuesOnConditionCheckFailure, the valid values are: NONE and ALL_OLD.



10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
# File 'lib/aws-sdk-dynamodb/types.rb', line 10408

class Update < Struct.new(
  :key,
  :update_expression,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

Name of the table for the UpdateItem request. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.



10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
# File 'lib/aws-sdk-dynamodb/types.rb', line 10408

class Update < Struct.new(
  :key,
  :update_expression,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end

#update_expressionString

An expression that defines one or more attributes to be updated, the action to be performed on them, and new value(s) for them.



10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
# File 'lib/aws-sdk-dynamodb/types.rb', line 10408

class Update < Struct.new(
  :key,
  :update_expression,
  :table_name,
  :condition_expression,
  :expression_attribute_names,
  :expression_attribute_values,
  :return_values_on_condition_check_failure)
  SENSITIVE = []
  include Aws::Structure
end