Class: Aws::DynamoDB::Types::UpdateContributorInsightsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contributor_insights_modeString

The updated mode of CloudWatch Contributor Insights that determines whether to monitor all access and throttled events or to track throttled events exclusively.



10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-dynamodb/types.rb', line 10500

class UpdateContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_status,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#contributor_insights_statusString

The status of contributor insights



10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-dynamodb/types.rb', line 10500

class UpdateContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_status,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the global secondary index, if applicable.



10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-dynamodb/types.rb', line 10500

class UpdateContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_status,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table.



10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-dynamodb/types.rb', line 10500

class UpdateContributorInsightsOutput < Struct.new(
  :table_name,
  :index_name,
  :contributor_insights_status,
  :contributor_insights_mode)
  SENSITIVE = []
  include Aws::Structure
end