Class: Aws::DynamoDB::Types::UpdateReplicationGroupMemberAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::UpdateReplicationGroupMemberAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents a replica to be modified.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_secondary_indexes ⇒ Array<Types::ReplicaGlobalSecondaryIndex>
Replica-specific global secondary index settings.
-
#kms_master_key_id ⇒ String
The KMS key of the replica that should be used for KMS encryption.
-
#on_demand_throughput_override ⇒ Types::OnDemandThroughputOverride
Overrides the maximum on-demand throughput for the replica table.
-
#provisioned_throughput_override ⇒ Types::ProvisionedThroughputOverride
Replica-specific provisioned throughput.
-
#region_name ⇒ String
The Region where the replica exists.
-
#table_class_override ⇒ String
Replica-specific table class.
Instance Attribute Details
#global_secondary_indexes ⇒ Array<Types::ReplicaGlobalSecondaryIndex>
Replica-specific global secondary index settings.
11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11145 class UpdateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#kms_master_key_id ⇒ String
The KMS key of the replica that should be used for KMS encryption.
To specify a key, use its key ID, Amazon Resource Name (ARN), alias
name, or alias ARN. Note that you should only provide this parameter
if the key is different from the default DynamoDB KMS key
alias/aws/dynamodb.
11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11145 class UpdateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#on_demand_throughput_override ⇒ Types::OnDemandThroughputOverride
Overrides the maximum on-demand throughput for the replica table.
11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11145 class UpdateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#provisioned_throughput_override ⇒ Types::ProvisionedThroughputOverride
Replica-specific provisioned throughput. If not specified, uses the source table's provisioned throughput settings.
11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11145 class UpdateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The Region where the replica exists.
11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11145 class UpdateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |
#table_class_override ⇒ String
Replica-specific table class. If not specified, uses the source table's table class.
11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11145 class UpdateReplicationGroupMemberAction < Struct.new( :region_name, :kms_master_key_id, :provisioned_throughput_override, :on_demand_throughput_override, :global_secondary_indexes, :table_class_override) SENSITIVE = [] include Aws::Structure end |