Class: Aws::DynamoDB::Types::VectorIndex

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Contains the configuration settings for a vector index, including the index name, vector attribute, dimensions, distance function, search schema, and projection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dimensionsInteger

The number of dimensions in each vector.

Returns:

  • (Integer)


11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516

class VectorIndex < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#distance_functionString

The distance function used to calculate similarity between vectors. Valid values: COSINE, EUCLIDEAN, DOT_PRODUCT.

Returns:

  • (String)


11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516

class VectorIndex < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the vector index.

Returns:

  • (String)


11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516

class VectorIndex < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#projectionTypes::Projection

Specifies attributes that are copied (projected) from the table into the vector index.

Returns:



11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516

class VectorIndex < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#search_schemaArray<Types::SearchSchemaElement>

The search schema that defines partition key and inline filter attributes for the vector index.

Returns:



11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516

class VectorIndex < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#vector_attributeTypes::VectorAttributeDefinition

The vector attribute configuration for the index.



11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516

class VectorIndex < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end