Class: Aws::DynamoDB::Types::VectorIndexDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Contains the current state and configuration of a vector index, including its status, size, item count, and the settings specified when the index was created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backfillingBoolean

Specifies whether the index is currently backfilling. During backfill, SearchVectors operations might return incomplete results.

Returns:

  • (Boolean)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#dimensionsInteger

The number of dimensions in each vector.

Returns:

  • (Integer)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#distance_functionString

The distance function used to calculate similarity between vectors.

Returns:

  • (String)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#index_arnString

The Amazon Resource Name (ARN) that uniquely identifies the vector index.

Returns:

  • (String)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the vector index.

Returns:

  • (String)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#index_size_bytesInteger

The total size of the vector index, in bytes. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.

Returns:

  • (Integer)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#index_statusString

The current state of the vector index:

  • CREATING - The index is being created.

  • ACTIVE - The index is ready for use.

  • DELETING - The index is being deleted.

Returns:

  • (String)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#item_countInteger

The number of items indexed in the vector index. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.

Returns:

  • (Integer)


11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#projectionTypes::Projection

Specifies attributes that are copied (projected) from the table into the vector index.

Returns:



11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#search_schemaArray<Types::SearchSchemaElement>

The search schema that defines partition key and inline filter attributes for the vector index.

Returns:



11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vector_attributeTypes::VectorAttributeDefinition

The vector attribute configuration for the index.



11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592

class VectorIndexDescription < Struct.new(
  :index_name,
  :search_schema,
  :projection,
  :vector_attribute,
  :dimensions,
  :distance_function,
  :index_status,
  :backfilling,
  :index_size_bytes,
  :item_count,
  :index_arn)
  SENSITIVE = []
  include Aws::Structure
end