Class: Aws::DynamoDB::Types::VectorIndexInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

Contains the configuration of a vector index as it existed at the time a backup was created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dimensionsInteger

The number of dimensions in each vector.

Returns:

  • (Integer)


11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639

class VectorIndexInfo < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#distance_functionString

The distance function used to calculate similarity between vectors.

Returns:

  • (String)


11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639

class VectorIndexInfo < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the vector index.

Returns:

  • (String)


11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639

class VectorIndexInfo < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#projectionTypes::Projection

Specifies attributes that are copied (projected) from the table into the vector index.

Returns:



11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639

class VectorIndexInfo < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#search_schemaArray<Types::SearchSchemaElement>

The search schema that defines partition key and inline filter attributes for the vector index.

Returns:



11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639

class VectorIndexInfo < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end

#vector_attributeTypes::VectorAttributeDefinition

The vector attribute configuration for the index.



11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639

class VectorIndexInfo < Struct.new(
  :index_name,
  :vector_attribute,
  :search_schema,
  :projection,
  :dimensions,
  :distance_function)
  SENSITIVE = []
  include Aws::Structure
end