Class: Aws::DynamoDB::Types::VectorIndexUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dynamodb/types.rb

Overview

A vector index to be added to or removed from a table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#createTypes::CreateVectorIndexAction

The configuration for creating a new vector index on the table.



11663
11664
11665
11666
11667
11668
# File 'lib/aws-sdk-dynamodb/types.rb', line 11663

class VectorIndexUpdate < Struct.new(
  :create,
  :delete)
  SENSITIVE = []
  include Aws::Structure
end

#deleteTypes::DeleteVectorIndexAction

The configuration for deleting an existing vector index from the table.



11663
11664
11665
11666
11667
11668
# File 'lib/aws-sdk-dynamodb/types.rb', line 11663

class VectorIndexUpdate < Struct.new(
  :create,
  :delete)
  SENSITIVE = []
  include Aws::Structure
end