Class: Aws::DynamoDB::Waiters::ContributorInsightsEnabled
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Waiters::ContributorInsightsEnabled
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-dynamodb/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ContributorInsightsEnabled
constructor
A new instance of ContributorInsightsEnabled.
-
#wait(params = {}) ⇒ Types::DescribeContributorInsightsOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ContributorInsightsEnabled
Returns a new instance of ContributorInsightsEnabled.
89 90 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 89
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
121 122 123 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 121 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeContributorInsightsOutput
Returns a response object which responds to the following methods:
- #table_name => String
- #index_name => String
- #contributor_insights_rule_list => Array<String>
- #contributor_insights_status => String
- #last_update_date_time => Time
- #failure_exception => Types::FailureException
- #contributor_insights_mode => String
116 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 116
def wait: (
|