Class: Aws::DynamoDB::Waiters::ExportCompleted
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Waiters::ExportCompleted
- Defined in:
- lib/aws-sdk-dynamodb/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ExportCompleted
constructor
A new instance of ExportCompleted.
-
#wait(params = {}) ⇒ Types::DescribeExportOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ExportCompleted
Returns a new instance of ExportCompleted.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 133 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 60, delay: 20, poller: Aws::Waiters::Poller.new( operation_name: :describe_export, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "export_description.export_status", "expected" => "COMPLETED" }, { "state" => "failure", "matcher" => "path", "argument" => "export_description.export_status", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
165 166 167 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 165 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeExportOutput
Returns a response object which responds to the following methods:
-
#export_description => Types::ExportDescription
160 161 162 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 160 def wait(params = {}) @waiter.wait(client: @client, params: params) end |