Class: Aws::DynamoDB::Waiters::ImportCompleted
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Waiters::ImportCompleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-dynamodb/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ImportCompleted
constructor
A new instance of ImportCompleted.
-
#wait(params = {}) ⇒ Types::DescribeImportOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ImportCompleted
Returns a new instance of ImportCompleted.
177 178 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 177
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
215 216 217 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 215 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeImportOutput
Returns a response object which responds to the following methods:
- #import_table_description => Types::ImportTableDescription
210 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 210
def wait: (
|