Class: Aws::DynamoDB::Waiters::KinesisStreamingDestinationActive

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-dynamodb/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ KinesisStreamingDestinationActive

Returns a new instance of KinesisStreamingDestinationActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 30
  • :delay (Integer) — default: 20
  • :before_attempt (Proc)
  • :before_wait (Proc)


227
228
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 227

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



259
260
261
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 259

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeKinesisStreamingDestinationOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :table_name (required, String)

    The name of the table being described. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.

Returns:



254
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 254

def wait: (