Class: Aws::DynamoDB::Waiters::TableExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-dynamodb/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ TableExists

Returns a new instance of TableExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 25
  • :delay (Integer) — default: 20
  • :before_attempt (Proc)
  • :before_wait (Proc)


271
272
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 271

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



302
303
304
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 302

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeTableOutput

Returns a response object which responds to the following methods:

  • #table => Types::TableDescription

Options Hash (params):

  • :table_name (required, String)

    The name of the table to describe. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.

Returns:



297
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 297

def wait: (