Class: Aws::DynamoDB::Types::CreateVectorIndexAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::CreateVectorIndexAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
A new vector index to be added to a table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Integer
The number of dimensions in each vector.
-
#distance_function ⇒ String
The distance function used to calculate similarity.
-
#index_name ⇒ String
The name of the vector index.
-
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
-
#search_schema ⇒ Array<Types::SearchSchemaElement>
The partition key and inline filter attribute definitions for the vector index.
-
#vector_attribute ⇒ Types::VectorAttributeDefinition
The attribute that contains vector embeddings.
Instance Attribute Details
#dimensions ⇒ Integer
The number of dimensions in each vector.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2266 class CreateVectorIndexAction < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#distance_function ⇒ String
The distance function used to calculate similarity. Valid values:
COSINE, EUCLIDEAN, DOT_PRODUCT.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2266 class CreateVectorIndexAction < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the vector index. Must be unique within the table.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2266 class CreateVectorIndexAction < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2266 class CreateVectorIndexAction < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#search_schema ⇒ Array<Types::SearchSchemaElement>
The partition key and inline filter attribute definitions for the vector index.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2266 class CreateVectorIndexAction < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#vector_attribute ⇒ Types::VectorAttributeDefinition
The attribute that contains vector embeddings. If multiple vector indexes reference the same attribute, they must all use the same number of dimensions.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2266 class CreateVectorIndexAction < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |