Class: Aws::DynamoDB::Types::DescribeContributorInsightsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::DescribeContributorInsightsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contributor_insights_mode ⇒ String
The mode of CloudWatch Contributor Insights for DynamoDB that determines which events are emitted.
-
#contributor_insights_rule_list ⇒ Array<String>
List of names of the associated contributor insights rules.
-
#contributor_insights_status ⇒ String
Current status of contributor insights.
-
#failure_exception ⇒ Types::FailureException
Returns information about the last failure that was encountered.
-
#index_name ⇒ String
The name of the global secondary index being described.
-
#last_update_date_time ⇒ Time
Timestamp of the last time the status was changed.
-
#table_name ⇒ String
The name of the table being described.
Instance Attribute Details
#contributor_insights_mode ⇒ String
The mode of CloudWatch Contributor Insights for DynamoDB that determines which events are emitted. Can be set to track all access and throttled events or throttled events only.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2833 class DescribeContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_rule_list, :contributor_insights_status, :last_update_date_time, :failure_exception, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#contributor_insights_rule_list ⇒ Array<String>
List of names of the associated contributor insights rules.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2833 class DescribeContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_rule_list, :contributor_insights_status, :last_update_date_time, :failure_exception, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#contributor_insights_status ⇒ String
Current status of contributor insights.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2833 class DescribeContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_rule_list, :contributor_insights_status, :last_update_date_time, :failure_exception, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#failure_exception ⇒ Types::FailureException
Returns information about the last failure that was encountered.
The most common exceptions for a FAILED status are:
-
LimitExceededException - Per-account Amazon CloudWatch Contributor Insights rule limit reached. Please disable Contributor Insights for other tables/indexes OR disable Contributor Insights rules before retrying.
-
AccessDeniedException - Amazon CloudWatch Contributor Insights rules cannot be modified due to insufficient permissions.
-
AccessDeniedException - Failed to create service-linked role for Contributor Insights due to insufficient permissions.
-
InternalServerError - Failed to create Amazon CloudWatch Contributor Insights rules. Please retry request.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2833 class DescribeContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_rule_list, :contributor_insights_status, :last_update_date_time, :failure_exception, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the global secondary index being described.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2833 class DescribeContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_rule_list, :contributor_insights_status, :last_update_date_time, :failure_exception, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#last_update_date_time ⇒ Time
Timestamp of the last time the status was changed.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2833 class DescribeContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_rule_list, :contributor_insights_status, :last_update_date_time, :failure_exception, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table being described.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 2833 class DescribeContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_rule_list, :contributor_insights_status, :last_update_date_time, :failure_exception, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |