Class: Aws::DynamoDB::Types::ExportDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ExportDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents the properties of the exported table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billed_size_bytes ⇒ Integer
The billable size of the table export.
-
#client_token ⇒ String
The client token that was provided for the export task.
-
#end_time ⇒ Time
The time at which the export task completed.
-
#export_arn ⇒ String
The Amazon Resource Name (ARN) of the table export.
-
#export_format ⇒ String
The format of the exported data.
-
#export_manifest ⇒ String
The name of the manifest file for the export task.
-
#export_status ⇒ String
Export can be in one of the following states: IN_PROGRESS, COMPLETED, or FAILED.
-
#export_time ⇒ Time
Point in time from which table data was exported.
-
#export_type ⇒ String
The type of export that was performed.
-
#failure_code ⇒ String
Status code for the result of the failed export.
-
#failure_message ⇒ String
Export failure reason description.
-
#incremental_export_specification ⇒ Types::IncrementalExportSpecification
Optional object containing the parameters specific to an incremental export.
-
#item_count ⇒ Integer
The number of items exported.
-
#s3_bucket ⇒ String
The name of the Amazon S3 bucket containing the export.
-
#s3_bucket_owner ⇒ String
The ID of the Amazon Web Services account that owns the bucket containing the export.
-
#s3_prefix ⇒ String
The Amazon S3 bucket prefix used as the file name and path of the exported snapshot.
-
#s3_sse_algorithm ⇒ String
Type of encryption used on the bucket where export data is stored.
-
#s3_sse_kms_key_id ⇒ String
The ID of the KMS managed key used to encrypt the S3 bucket where export data is stored (if applicable).
-
#start_time ⇒ Time
The time at which the export task began.
-
#table_arn ⇒ String
The Amazon Resource Name (ARN) of the table that was exported.
-
#table_id ⇒ String
Unique ID of the table that was exported.
Instance Attribute Details
#billed_size_bytes ⇒ Integer
The billable size of the table export.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The client token that was provided for the export task. A client
token makes calls to ExportTableToPointInTimeInput idempotent,
meaning that multiple identical calls have the same effect as one
single call.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The time at which the export task completed.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#export_arn ⇒ String
The Amazon Resource Name (ARN) of the table export.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#export_format ⇒ String
The format of the exported data. Valid values for ExportFormat are
DYNAMODB_JSON or ION.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#export_manifest ⇒ String
The name of the manifest file for the export task.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#export_status ⇒ String
Export can be in one of the following states: IN_PROGRESS, COMPLETED, or FAILED.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#export_time ⇒ Time
Point in time from which table data was exported.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#export_type ⇒ String
The type of export that was performed. Valid values are
FULL_EXPORT or INCREMENTAL_EXPORT.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
Status code for the result of the failed export.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
Export failure reason description.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#incremental_export_specification ⇒ Types::IncrementalExportSpecification
Optional object containing the parameters specific to an incremental export.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#item_count ⇒ Integer
The number of items exported.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The name of the Amazon S3 bucket containing the export.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner ⇒ String
The ID of the Amazon Web Services account that owns the bucket containing the export.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#s3_prefix ⇒ String
The Amazon S3 bucket prefix used as the file name and path of the exported snapshot.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#s3_sse_algorithm ⇒ String
Type of encryption used on the bucket where export data is stored.
Valid values for S3SseAlgorithm are:
-
AES256- server-side encryption with Amazon S3 managed keys -
KMS- server-side encryption with KMS managed keys
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#s3_sse_kms_key_id ⇒ String
The ID of the KMS managed key used to encrypt the S3 bucket where export data is stored (if applicable).
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time at which the export task began.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#table_arn ⇒ String
The Amazon Resource Name (ARN) of the table that was exported.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |
#table_id ⇒ String
Unique ID of the table that was exported.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 3830 class ExportDescription < Struct.new( :export_arn, :export_status, :start_time, :end_time, :export_manifest, :table_arn, :table_id, :export_time, :client_token, :s3_bucket, :s3_bucket_owner, :s3_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :failure_code, :failure_message, :export_format, :billed_size_bytes, :item_count, :export_type, :incremental_export_specification) SENSITIVE = [] include Aws::Structure end |