Class: Aws::DynamoDB::Types::ImportTableDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ImportTableDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents the properties of the table being imported into.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token that was provided for the import task.
-
#cloud_watch_log_group_arn ⇒ String
The Amazon Resource Number (ARN) of the Cloudwatch Log Group associated with the target table.
-
#end_time ⇒ Time
The time at which the creation of the table associated with this import task completed.
-
#error_count ⇒ Integer
The number of errors occurred on importing the source file into the target table.
-
#failure_code ⇒ String
The error code corresponding to the failure that the import job ran into during execution.
-
#failure_message ⇒ String
The error message corresponding to the failure that the import job ran into during execution.
-
#import_arn ⇒ String
The Amazon Resource Number (ARN) corresponding to the import request.
-
#import_status ⇒ String
The status of the import.
-
#imported_item_count ⇒ Integer
The number of items successfully imported into the new table.
-
#input_compression_type ⇒ String
The compression options for the data that has been imported into the target table.
-
#input_format ⇒ String
The format of the source data going into the target table.
-
#input_format_options ⇒ Types::InputFormatOptions
The format options for the data that was imported into the target table.
-
#processed_item_count ⇒ Integer
The total number of items processed from the source file.
-
#processed_size_bytes ⇒ Integer
The total size of data processed from the source file, in Bytes.
-
#s3_bucket_source ⇒ Types::S3BucketSource
Values for the S3 bucket the source file is imported from.
-
#start_time ⇒ Time
The time when this import task started.
-
#table_arn ⇒ String
The Amazon Resource Number (ARN) of the table being imported into.
-
#table_creation_parameters ⇒ Types::TableCreationParameters
The parameters for the new table that is being imported into.
-
#table_id ⇒ String
The table id corresponding to the table created by import table process.
Instance Attribute Details
#client_token ⇒ String
The client token that was provided for the import task. Reusing the
client token on retry makes a call to ImportTable idempotent.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#cloud_watch_log_group_arn ⇒ String
The Amazon Resource Number (ARN) of the Cloudwatch Log Group associated with the target table.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The time at which the creation of the table associated with this import task completed.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#error_count ⇒ Integer
The number of errors occurred on importing the source file into the target table.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
The error code corresponding to the failure that the import job ran into during execution.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
The error message corresponding to the failure that the import job ran into during execution.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#import_arn ⇒ String
The Amazon Resource Number (ARN) corresponding to the import request.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
The status of the import.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#imported_item_count ⇒ Integer
The number of items successfully imported into the new table.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#input_compression_type ⇒ String
The compression options for the data that has been imported into the target table. The values are NONE, GZIP, or ZSTD.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#input_format ⇒ String
The format of the source data going into the target table.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#input_format_options ⇒ Types::InputFormatOptions
The format options for the data that was imported into the target table. There is one value, CsvOption.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#processed_item_count ⇒ Integer
The total number of items processed from the source file.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#processed_size_bytes ⇒ Integer
The total size of data processed from the source file, in Bytes.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_source ⇒ Types::S3BucketSource
Values for the S3 bucket the source file is imported from. Includes bucket name (required), key prefix (optional) and bucket account owner ID (optional).
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time when this import task started.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#table_arn ⇒ String
The Amazon Resource Number (ARN) of the table being imported into.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#table_creation_parameters ⇒ Types::TableCreationParameters
The parameters for the new table that is being imported into.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#table_id ⇒ String
The table id corresponding to the table created by import table process.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 4972 class ImportTableDescription < Struct.new( :import_arn, :import_status, :table_arn, :table_id, :client_token, :s3_bucket_source, :error_count, :cloud_watch_log_group_arn, :input_format, :input_format_options, :input_compression_type, :table_creation_parameters, :start_time, :end_time, :processed_size_bytes, :processed_item_count, :imported_item_count, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |