Class: Aws::DynamoDB::Types::LocalSecondaryIndexInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::LocalSecondaryIndexInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Represents the properties of a local secondary index for the table when the backup was created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#index_name ⇒ String
Represents the name of the local secondary index.
-
#key_schema ⇒ Array<Types::KeySchemaElement>
The complete key schema for a local secondary index, which consists of one or more pairs of attribute names and key types:.
-
#projection ⇒ Types::Projection
Represents attributes that are copied (projected) from the table into the global secondary index.
Instance Attribute Details
#index_name ⇒ String
Represents the name of the local secondary index.
6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6013 class LocalSecondaryIndexInfo < Struct.new( :index_name, :key_schema, :projection) SENSITIVE = [] include Aws::Structure end |
#key_schema ⇒ Array<Types::KeySchemaElement>
The complete key schema for a local secondary index, which consists of one or more pairs of attribute names and key types:
-
HASH- partition key -
RANGE- sort key
The sort key of an item is also known as its range attribute. The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6013 class LocalSecondaryIndexInfo < Struct.new( :index_name, :key_schema, :projection) SENSITIVE = [] include Aws::Structure end |
#projection ⇒ Types::Projection
Represents attributes that are copied (projected) from the table into the global secondary index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 6013 class LocalSecondaryIndexInfo < Struct.new( :index_name, :key_schema, :projection) SENSITIVE = [] include Aws::Structure end |