Class: Aws::DynamoDB::Types::RequestLimitExceeded
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::RequestLimitExceeded
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Throughput exceeds the current throughput quota for your account. For detailed information about why the request was throttled and the ARN of the impacted resource, find the ThrottlingReason field in the returned exception. Contact Amazon Web Services Support to request a quota increase.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of [ThrottlingReason][1] that provide detailed diagnostic information about why the request was throttled.
Instance Attribute Details
#message ⇒ String
8007 8008 8009 8010 8011 8012 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8007 class RequestLimitExceeded < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of ThrottlingReason that provide detailed diagnostic information about why the request was throttled.
8007 8008 8009 8010 8011 8012 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8007 class RequestLimitExceeded < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |