Class: Aws::DynamoDB::Types::RestoreTableFromBackupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::RestoreTableFromBackupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_arn ⇒ String
The Amazon Resource Name (ARN) associated with the backup.
-
#billing_mode_override ⇒ String
The billing mode of the restored table.
-
#global_secondary_index_override ⇒ Array<Types::GlobalSecondaryIndex>
List of global secondary indexes for the restored table.
-
#local_secondary_index_override ⇒ Array<Types::LocalSecondaryIndex>
List of local secondary indexes for the restored table.
-
#on_demand_throughput_override ⇒ Types::OnDemandThroughput
Sets the maximum number of read and write units for the specified on-demand table.
-
#provisioned_throughput_override ⇒ Types::ProvisionedThroughput
Provisioned throughput settings for the restored table.
-
#sse_specification_override ⇒ Types::SSESpecification
The new server-side encryption settings for the restored table.
-
#target_table_name ⇒ String
The name of the new table to which the backup must be restored.
-
#vector_index_override ⇒ Array<Types::VectorIndex>
The vector indexes for the restored table.
Instance Attribute Details
#backup_arn ⇒ String
The Amazon Resource Name (ARN) associated with the backup.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#billing_mode_override ⇒ String
The billing mode of the restored table.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#global_secondary_index_override ⇒ Array<Types::GlobalSecondaryIndex>
List of global secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#local_secondary_index_override ⇒ Array<Types::LocalSecondaryIndex>
List of local secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#on_demand_throughput_override ⇒ Types::OnDemandThroughput
Sets the maximum number of read and write units for the specified
on-demand table. If you use this parameter, you must specify
MaxReadRequestUnits, MaxWriteRequestUnits, or both.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#provisioned_throughput_override ⇒ Types::ProvisionedThroughput
Provisioned throughput settings for the restored table.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#sse_specification_override ⇒ Types::SSESpecification
The new server-side encryption settings for the restored table.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#target_table_name ⇒ String
The name of the new table to which the backup must be restored.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#vector_index_override ⇒ Array<Types::VectorIndex>
The vector indexes for the restored table. If not specified, all vector indexes from the backup are restored. The indexes provided must match existing vector indexes from the backup. You can choose to exclude some or all of the vector indexes at the time of restore.
8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8131 class RestoreTableFromBackupInput < Struct.new( :target_table_name, :backup_arn, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |