Class: Aws::DynamoDB::Types::RestoreTableToPointInTimeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::RestoreTableToPointInTimeInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_mode_override ⇒ String
The billing mode of the restored table.
-
#global_secondary_index_override ⇒ Array<Types::GlobalSecondaryIndex>
List of global secondary indexes for the restored table.
-
#local_secondary_index_override ⇒ Array<Types::LocalSecondaryIndex>
List of local secondary indexes for the restored table.
-
#on_demand_throughput_override ⇒ Types::OnDemandThroughput
Sets the maximum number of read and write units for the specified on-demand table.
-
#provisioned_throughput_override ⇒ Types::ProvisionedThroughput
Provisioned throughput settings for the restored table.
-
#restore_date_time ⇒ Time
Time in the past to restore the table to.
-
#source_table_arn ⇒ String
The DynamoDB table that will be restored.
-
#source_table_name ⇒ String
Name of the source table that is being restored.
-
#sse_specification_override ⇒ Types::SSESpecification
The new server-side encryption settings for the restored table.
-
#target_table_name ⇒ String
The name of the new table to which it must be restored to.
-
#use_latest_restorable_time ⇒ Boolean
Restore the table to the latest possible time.
-
#vector_index_override ⇒ Array<Types::VectorIndex>
The vector indexes for the restored table.
Instance Attribute Details
#billing_mode_override ⇒ String
The billing mode of the restored table.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#global_secondary_index_override ⇒ Array<Types::GlobalSecondaryIndex>
List of global secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.
The WarmThroughput setting is not supported on global secondary
indexes when you use RestoreTableToPointInTime. Although
WarmThroughput appears in the shared index definition, including
it in a GlobalSecondaryIndexOverride entry causes the request to
fail with a validation error.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#local_secondary_index_override ⇒ Array<Types::LocalSecondaryIndex>
List of local secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#on_demand_throughput_override ⇒ Types::OnDemandThroughput
Sets the maximum number of read and write units for the specified
on-demand table. If you use this parameter, you must specify
MaxReadRequestUnits, MaxWriteRequestUnits, or both.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#provisioned_throughput_override ⇒ Types::ProvisionedThroughput
Provisioned throughput settings for the restored table.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#restore_date_time ⇒ Time
Time in the past to restore the table to.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#source_table_arn ⇒ String
The DynamoDB table that will be restored. This value is an Amazon Resource Name (ARN).
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#source_table_name ⇒ String
Name of the source table that is being restored.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#sse_specification_override ⇒ Types::SSESpecification
The new server-side encryption settings for the restored table.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#target_table_name ⇒ String
The name of the new table to which it must be restored to.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#use_latest_restorable_time ⇒ Boolean
Restore the table to the latest possible time.
LatestRestorableDateTime is typically 5 minutes before the current
time.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |
#vector_index_override ⇒ Array<Types::VectorIndex>
The vector indexes for the restored table. If not specified, all vector indexes from the source table are restored. The indexes provided must match existing vector indexes from the source table. You can choose to exclude some or all of the vector indexes at the time of restore.
8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8226 class RestoreTableToPointInTimeInput < Struct.new( :source_table_arn, :source_table_name, :target_table_name, :use_latest_restorable_time, :restore_date_time, :billing_mode_override, :global_secondary_index_override, :local_secondary_index_override, :provisioned_throughput_override, :on_demand_throughput_override, :sse_specification_override, :vector_index_override) SENSITIVE = [] include Aws::Structure end |