Class: Aws::DynamoDB::Types::SearchResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::SearchResultItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
A single result from a SearchVectors operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#item ⇒ Hash<String,Types::AttributeValue>
A map of attribute names to
AttributeValueobjects, representing the projected attributes of the item returned by the vector search. -
#score ⇒ Float
The similarity score for this item relative to the search vector.
Instance Attribute Details
#item ⇒ Hash<String,Types::AttributeValue>
A map of attribute names to AttributeValue objects, representing
the projected attributes of the item returned by the vector search.
8800 8801 8802 8803 8804 8805 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8800 class SearchResultItem < Struct.new( :item, :score) SENSITIVE = [] include Aws::Structure end |
#score ⇒ Float
The similarity score for this item relative to the search vector. The interpretation depends on the distance function configured for the vector index.
8800 8801 8802 8803 8804 8805 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8800 class SearchResultItem < Struct.new( :item, :score) SENSITIVE = [] include Aws::Structure end |