Class: Aws::DynamoDB::Types::SearchSchemaElement
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::SearchSchemaElement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
An element in the search schema of a vector index.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The name of the attribute.
-
#search_schema_element_type ⇒ String
The role of the attribute in the search schema.
Instance Attribute Details
#attribute_name ⇒ String
The name of the attribute.
8827 8828 8829 8830 8831 8832 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8827 class SearchSchemaElement < Struct.new( :attribute_name, :search_schema_element_type) SENSITIVE = [] include Aws::Structure end |
#search_schema_element_type ⇒ String
The role of the attribute in the search schema. Valid values:
-
HASH- A partition key that partitions the vector index for independent scaling. When specified, you must provide this attribute's value in theSearchConditionExpression. -
INLINE_FILTER- An attribute projected into the vector index for filtering at the storage layer during search. Inline filters are optional in theSearchConditionExpression.
8827 8828 8829 8830 8831 8832 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8827 class SearchSchemaElement < Struct.new( :attribute_name, :search_schema_element_type) SENSITIVE = [] include Aws::Structure end |