Class: Aws::DynamoDB::Types::SearchVectorsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::SearchVectorsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expression_attribute_names ⇒ Hash<String,String>
One or more substitution tokens for attribute names in an expression.
-
#expression_attribute_values ⇒ Hash<String,Types::AttributeValue>
One or more values that can be substituted in an expression.
-
#index_name ⇒ String
The name of the vector index to search.
-
#projection_expression ⇒ String
A string that identifies one or more attributes to retrieve from the index.
-
#return_consumed_capacity ⇒ String
Determines the level of detail about either provisioned or on-demand throughput consumption that is returned in the response:.
-
#search_condition_expression ⇒ String
A condition expression used to filter the vector search results.
-
#search_vector ⇒ Array<Types::AttributeValue>
The search vector to compare against the indexed vectors.
-
#table_name ⇒ String
The name or Amazon Resource Name (ARN) of the table containing the vector index.
-
#top_k ⇒ Integer
The number of most similar results to return.
Instance Attribute Details
#expression_attribute_names ⇒ Hash<String,String>
One or more substitution tokens for attribute names in an
expression. Use the # character in an expression to dereference an
attribute name.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#expression_attribute_values ⇒ Hash<String,Types::AttributeValue>
One or more values that can be substituted in an expression. Use the
: character in an expression to dereference an attribute value.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the vector index to search. The index must be in the
ACTIVE state.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#projection_expression ⇒ String
A string that identifies one or more attributes to retrieve from the index. Separate attribute names with commas. If not specified, the operation returns all attributes projected into the vector index.
Only attributes projected into the vector index can be retrieved.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#return_consumed_capacity ⇒ String
Determines the level of detail about either provisioned or on-demand throughput consumption that is returned in the response:
-
INDEXES- The response includes the aggregateConsumedCapacityfor the operation, together withConsumedCapacityfor each table and secondary index that was accessed.Note that some operations, such as
GetItemandBatchGetItem, do not access any indexes at all. In these cases, specifyingINDEXESwill only returnConsumedCapacityinformation for table(s). -
TOTAL- The response includes only the aggregateConsumedCapacityfor the operation. -
NONE- NoConsumedCapacitydetails are included in the response.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#search_condition_expression ⇒ String
A condition expression used to filter the vector search results. The
expression can reference attributes defined in the vector index
search schema, including HASH and INLINE_FILTER key elements.
Only the equality operator (=) is supported for HASH attributes.
Comparison and range operators are supported for INLINE_FILTER
attributes. Only top-level attributes from the search schema can be
referenced.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#search_vector ⇒ Array<Types::AttributeValue>
The search vector to compare against the indexed vectors. Each element is a 32-bit IEEE-754 floating point number, provided in DynamoDB list format.
The number of dimensions must match the number of dimensions configured for the vector index.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name or Amazon Resource Name (ARN) of the table containing the vector index.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |
#top_k ⇒ Integer
The number of most similar results to return.
8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 8909 class SearchVectorsInput < Struct.new( :table_name, :index_name, :return_consumed_capacity, :expression_attribute_names, :expression_attribute_values, :projection_expression, :search_vector, :search_condition_expression, :top_k) SENSITIVE = [] include Aws::Structure end |