Class: Aws::DynamoDB::Types::TableCreationParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::TableCreationParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
The parameters for the table created as part of the import operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_definitions ⇒ Array<Types::AttributeDefinition>
The attributes of the table created as part of the import operation.
-
#billing_mode ⇒ String
The billing mode for provisioning the table created as part of the import operation.
-
#global_secondary_indexes ⇒ Array<Types::GlobalSecondaryIndex>
The Global Secondary Indexes (GSI) of the table to be created as part of the import operation.
-
#key_schema ⇒ Array<Types::KeySchemaElement>
The primary key and option sort key of the table created as part of the import operation.
-
#on_demand_throughput ⇒ Types::OnDemandThroughput
Sets the maximum number of read and write units for the specified on-demand table.
-
#provisioned_throughput ⇒ Types::ProvisionedThroughput
Represents the provisioned throughput settings for the specified global secondary index.
-
#sse_specification ⇒ Types::SSESpecification
Represents the settings used to enable server-side encryption.
-
#table_name ⇒ String
The name of the table created as part of the import operation.
-
#vector_indexes ⇒ Array<Types::VectorIndex>
The vector indexes of the table to be created as part of the import operation.
Instance Attribute Details
#attribute_definitions ⇒ Array<Types::AttributeDefinition>
The attributes of the table created as part of the import operation.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#billing_mode ⇒ String
The billing mode for provisioning the table created as part of the import operation.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#global_secondary_indexes ⇒ Array<Types::GlobalSecondaryIndex>
The Global Secondary Indexes (GSI) of the table to be created as part of the import operation.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#key_schema ⇒ Array<Types::KeySchemaElement>
The primary key and option sort key of the table created as part of the import operation.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#on_demand_throughput ⇒ Types::OnDemandThroughput
Sets the maximum number of read and write units for the specified
on-demand table. If you use this parameter, you must specify
MaxReadRequestUnits, MaxWriteRequestUnits, or both.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#provisioned_throughput ⇒ Types::ProvisionedThroughput
Represents the provisioned throughput settings for the specified
global secondary index. You must use ProvisionedThroughput or
OnDemandThroughput based on your table’s capacity mode.
For current minimum and maximum provisioned throughput values, see Service, Account, and Table Quotas in the Amazon DynamoDB Developer Guide.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#sse_specification ⇒ Types::SSESpecification
Represents the settings used to enable server-side encryption.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table created as part of the import operation.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |
#vector_indexes ⇒ Array<Types::VectorIndex>
The vector indexes of the table to be created as part of the import operation.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9218 class TableCreationParameters < Struct.new( :table_name, :attribute_definitions, :key_schema, :billing_mode, :provisioned_throughput, :on_demand_throughput, :sse_specification, :global_secondary_indexes, :vector_indexes) SENSITIVE = [] include Aws::Structure end |