Class: Aws::DynamoDB::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
The request was denied due to request throttling. For detailed information about why the request was throttled and the ARN of the impacted resource, find the ThrottlingReason field in the returned exception.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of [ThrottlingReason][1] that provide detailed diagnostic information about why the request was throttled.
Instance Attribute Details
#message ⇒ String
9792 9793 9794 9795 9796 9797 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9792 class ThrottlingException < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of ThrottlingReason that provide detailed diagnostic information about why the request was throttled.
9792 9793 9794 9795 9796 9797 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 9792 class ThrottlingException < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |