Class: Aws::DynamoDB::Types::TransactWriteItemsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::TransactWriteItemsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumed_capacity ⇒ Array<Types::ConsumedCapacity>
The capacity units consumed by the entire
TransactWriteItemsoperation. -
#item_collection_metrics ⇒ Hash<String,Array<Types::ItemCollectionMetrics>>
A list of tables that were processed by
TransactWriteItemsand, for each table, information about any item collections that were affected by individualUpdateItem,PutItem, orDeleteItemoperations.
Instance Attribute Details
#consumed_capacity ⇒ Array<Types::ConsumedCapacity>
The capacity units consumed by the entire TransactWriteItems
operation. The values of the list are ordered according to the
ordering of the TransactItems request parameter.
If the table has vector indexes, each element also includes a
VectorIndexes field with VectorWriteRequestBytes consumed for
each affected vector index.
10096 10097 10098 10099 10100 10101 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 10096 class TransactWriteItemsOutput < Struct.new( :consumed_capacity, :item_collection_metrics) SENSITIVE = [] include Aws::Structure end |
#item_collection_metrics ⇒ Hash<String,Array<Types::ItemCollectionMetrics>>
A list of tables that were processed by TransactWriteItems and,
for each table, information about any item collections that were
affected by individual UpdateItem, PutItem, or DeleteItem
operations.
10096 10097 10098 10099 10100 10101 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 10096 class TransactWriteItemsOutput < Struct.new( :consumed_capacity, :item_collection_metrics) SENSITIVE = [] include Aws::Structure end |