Class: Aws::DynamoDB::Types::UpdateContributorInsightsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::UpdateContributorInsightsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contributor_insights_mode ⇒ String
The updated mode of CloudWatch Contributor Insights that determines whether to monitor all access and throttled events or to track throttled events exclusively.
-
#contributor_insights_status ⇒ String
The status of contributor insights.
-
#index_name ⇒ String
The name of the global secondary index, if applicable.
-
#table_name ⇒ String
The name of the table.
Instance Attribute Details
#contributor_insights_mode ⇒ String
The updated mode of CloudWatch Contributor Insights that determines whether to monitor all access and throttled events or to track throttled events exclusively.
10119 10120 10121 10122 10123 10124 10125 10126 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 10119 class UpdateContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#contributor_insights_status ⇒ String
The status of contributor insights
10119 10120 10121 10122 10123 10124 10125 10126 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 10119 class UpdateContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the global secondary index, if applicable.
10119 10120 10121 10122 10123 10124 10125 10126 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 10119 class UpdateContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table.
10119 10120 10121 10122 10123 10124 10125 10126 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 10119 class UpdateContributorInsightsOutput < Struct.new( :table_name, :index_name, :contributor_insights_status, :contributor_insights_mode) SENSITIVE = [] include Aws::Structure end |