Class: Aws::DynamoDB::Types::VectorIndex
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::VectorIndex
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Contains the configuration settings for a vector index, including the index name, vector attribute, dimensions, distance function, search schema, and projection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Integer
The number of dimensions in each vector.
-
#distance_function ⇒ String
The distance function used to calculate similarity between vectors.
-
#index_name ⇒ String
The name of the vector index.
-
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
-
#search_schema ⇒ Array<Types::SearchSchemaElement>
The search schema that defines partition key and inline filter attributes for the vector index.
-
#vector_attribute ⇒ Types::VectorAttributeDefinition
The vector attribute configuration for the index.
Instance Attribute Details
#dimensions ⇒ Integer
The number of dimensions in each vector.
11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516 class VectorIndex < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#distance_function ⇒ String
The distance function used to calculate similarity between vectors.
Valid values: COSINE, EUCLIDEAN, DOT_PRODUCT.
11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516 class VectorIndex < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the vector index.
11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516 class VectorIndex < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516 class VectorIndex < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#search_schema ⇒ Array<Types::SearchSchemaElement>
The search schema that defines partition key and inline filter attributes for the vector index.
11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516 class VectorIndex < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#vector_attribute ⇒ Types::VectorAttributeDefinition
The vector attribute configuration for the index.
11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11516 class VectorIndex < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |