Class: Aws::DynamoDB::Types::VectorIndexDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::VectorIndexDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Contains the current state and configuration of a vector index, including its status, size, item count, and the settings specified when the index was created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backfilling ⇒ Boolean
Specifies whether the index is currently backfilling.
-
#dimensions ⇒ Integer
The number of dimensions in each vector.
-
#distance_function ⇒ String
The distance function used to calculate similarity between vectors.
-
#index_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the vector index.
-
#index_name ⇒ String
The name of the vector index.
-
#index_size_bytes ⇒ Integer
The total size of the vector index, in bytes.
-
#index_status ⇒ String
The current state of the vector index:.
-
#item_count ⇒ Integer
The number of items indexed in the vector index.
-
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
-
#search_schema ⇒ Array<Types::SearchSchemaElement>
The search schema that defines partition key and inline filter attributes for the vector index.
-
#vector_attribute ⇒ Types::VectorAttributeDefinition
The vector attribute configuration for the index.
Instance Attribute Details
#backfilling ⇒ Boolean
Specifies whether the index is currently backfilling. During
backfill, SearchVectors operations might return incomplete
results.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Integer
The number of dimensions in each vector.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#distance_function ⇒ String
The distance function used to calculate similarity between vectors.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#index_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the vector index.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the vector index.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#index_size_bytes ⇒ Integer
The total size of the vector index, in bytes. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#index_status ⇒ String
The current state of the vector index:
-
CREATING- The index is being created. -
ACTIVE- The index is ready for use. -
DELETING- The index is being deleted.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#item_count ⇒ Integer
The number of items indexed in the vector index. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#search_schema ⇒ Array<Types::SearchSchemaElement>
The search schema that defines partition key and inline filter attributes for the vector index.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |
#vector_attribute ⇒ Types::VectorAttributeDefinition
The vector attribute configuration for the index.
11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 11602 11603 11604 11605 11606 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11592 class VectorIndexDescription < Struct.new( :index_name, :search_schema, :projection, :vector_attribute, :dimensions, :distance_function, :index_status, :backfilling, :index_size_bytes, :item_count, :index_arn) SENSITIVE = [] include Aws::Structure end |