Class: Aws::DynamoDB::Types::VectorIndexInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::DynamoDB::Types::VectorIndexInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dynamodb/types.rb
Overview
Contains the configuration of a vector index as it existed at the time a backup was created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Integer
The number of dimensions in each vector.
-
#distance_function ⇒ String
The distance function used to calculate similarity between vectors.
-
#index_name ⇒ String
The name of the vector index.
-
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
-
#search_schema ⇒ Array<Types::SearchSchemaElement>
The search schema that defines partition key and inline filter attributes for the vector index.
-
#vector_attribute ⇒ Types::VectorAttributeDefinition
The vector attribute configuration for the index.
Instance Attribute Details
#dimensions ⇒ Integer
The number of dimensions in each vector.
11639 11640 11641 11642 11643 11644 11645 11646 11647 11648 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639 class VectorIndexInfo < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#distance_function ⇒ String
The distance function used to calculate similarity between vectors.
11639 11640 11641 11642 11643 11644 11645 11646 11647 11648 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639 class VectorIndexInfo < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#index_name ⇒ String
The name of the vector index.
11639 11640 11641 11642 11643 11644 11645 11646 11647 11648 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639 class VectorIndexInfo < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#projection ⇒ Types::Projection
Specifies attributes that are copied (projected) from the table into the vector index.
11639 11640 11641 11642 11643 11644 11645 11646 11647 11648 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639 class VectorIndexInfo < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#search_schema ⇒ Array<Types::SearchSchemaElement>
The search schema that defines partition key and inline filter attributes for the vector index.
11639 11640 11641 11642 11643 11644 11645 11646 11647 11648 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639 class VectorIndexInfo < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |
#vector_attribute ⇒ Types::VectorAttributeDefinition
The vector attribute configuration for the index.
11639 11640 11641 11642 11643 11644 11645 11646 11647 11648 |
# File 'lib/aws-sdk-dynamodb/types.rb', line 11639 class VectorIndexInfo < Struct.new( :index_name, :vector_attribute, :search_schema, :projection, :dimensions, :distance_function) SENSITIVE = [] include Aws::Structure end |