Class: Aws::DynamoDB::Waiters::ContributorInsightsEnabled
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Waiters::ContributorInsightsEnabled
- Defined in:
- lib/aws-sdk-dynamodb/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ContributorInsightsEnabled
constructor
A new instance of ContributorInsightsEnabled.
-
#wait(params = {}) ⇒ Types::DescribeContributorInsightsOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ContributorInsightsEnabled
Returns a new instance of ContributorInsightsEnabled.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 89 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 30, delay: 20, poller: Aws::Waiters::Poller.new( operation_name: :describe_contributor_insights, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "contributor_insights_status", "expected" => "ENABLED" }, { "state" => "failure", "matcher" => "path", "argument" => "contributor_insights_status", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
121 122 123 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 121 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeContributorInsightsOutput
Returns a response object which responds to the following methods:
-
#table_name => String
-
#index_name => String
-
#contributor_insights_rule_list => Array<String>
-
#contributor_insights_status => String
-
#last_update_date_time => Time
-
#failure_exception => Types::FailureException
-
#contributor_insights_mode => String
116 117 118 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 116 def wait(params = {}) @waiter.wait(client: @client, params: params) end |