Class: Aws::DynamoDB::Waiters::ImportCompleted
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Waiters::ImportCompleted
- Defined in:
- lib/aws-sdk-dynamodb/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ImportCompleted
constructor
A new instance of ImportCompleted.
-
#wait(params = {}) ⇒ Types::DescribeImportOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ImportCompleted
Returns a new instance of ImportCompleted.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 177 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 60, delay: 20, poller: Aws::Waiters::Poller.new( operation_name: :describe_import, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "import_table_description.import_status", "expected" => "COMPLETED" }, { "state" => "failure", "matcher" => "path", "argument" => "import_table_description.import_status", "expected" => "FAILED" }, { "state" => "failure", "matcher" => "path", "argument" => "import_table_description.import_status", "expected" => "CANCELLED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
215 216 217 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 215 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeImportOutput
Returns a response object which responds to the following methods:
-
#import_table_description => Types::ImportTableDescription
210 211 212 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 210 def wait(params = {}) @waiter.wait(client: @client, params: params) end |