Class: Aws::DynamoDB::Waiters::KinesisStreamingDestinationActive
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Waiters::KinesisStreamingDestinationActive
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-dynamodb/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ KinesisStreamingDestinationActive
constructor
A new instance of KinesisStreamingDestinationActive.
-
#wait(params = {}) ⇒ Types::DescribeKinesisStreamingDestinationOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ KinesisStreamingDestinationActive
Returns a new instance of KinesisStreamingDestinationActive.
227 228 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 227
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
259 260 261 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 259 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeKinesisStreamingDestinationOutput
Returns a response object which responds to the following methods:
- #table_name => String
- #kinesis_data_stream_destinations => Array<Types::KinesisDataStreamDestination>
254 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 254
def wait: (
|