Class: Aws::DynamoDB::Waiters::TableExists
- Inherits:
-
Object
- Object
- Aws::DynamoDB::Waiters::TableExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-dynamodb/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ TableExists
constructor
A new instance of TableExists.
-
#wait(params = {}) ⇒ Types::DescribeTableOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ TableExists
Returns a new instance of TableExists.
271 272 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 271
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
302 303 304 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 302 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeTableOutput
Returns a response object which responds to the following methods:
- #table => Types::TableDescription
297 |
# File 'lib/aws-sdk-dynamodb/waiters.rb', line 297
def wait: (
|